/* defaultConfig.c generated by valac 0.56.18, the Vala compiler
 * generated from defaultConfig.vala, do not modify */

/*///////////////////////////////////////////////////////////////////////*/
/* Copyright 2011-2021 Simon Schneegans*/
/**/
/* Permission is hereby granted, free of charge, to any person obtaining*/
/* a copy of this software and associated documentation files (the*/
/* "Software"), to deal in the Software without restriction, including*/
/* without limitation the rights to use, copy, modify, merge, publish,*/
/* distribute, sublicense, and/or sell copies of the Software, and to*/
/* permit persons to whom the Software is furnished to do so, subject to*/
/* the following conditions:*/
/* */
/* The above copyright notice and this permission notice shall be*/
/* included in all copies or substantial portions of the Software.*/
/* */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,*/
/* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF*/
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*/
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY*/
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,*/
/* TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE*/
/* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.*/
/*///////////////////////////////////////////////////////////////////////*/

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <glib/gi18n-lib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GNOME_PIE_TYPE_PIE (gnome_pie_pie_get_type ())
#define GNOME_PIE_PIE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_PIE, GnomePiePie))
#define GNOME_PIE_PIE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_PIE, GnomePiePieClass))
#define GNOME_PIE_IS_PIE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_PIE))
#define GNOME_PIE_IS_PIE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_PIE))
#define GNOME_PIE_PIE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_PIE, GnomePiePieClass))

typedef struct _GnomePiePie GnomePiePie;
typedef struct _GnomePiePieClass GnomePiePieClass;

#define GNOME_PIE_TYPE_TRIGGER (gnome_pie_trigger_get_type ())
#define GNOME_PIE_TRIGGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_TRIGGER, GnomePieTrigger))
#define GNOME_PIE_TRIGGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_TRIGGER, GnomePieTriggerClass))
#define GNOME_PIE_IS_TRIGGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_TRIGGER))
#define GNOME_PIE_IS_TRIGGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_TRIGGER))
#define GNOME_PIE_TRIGGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_TRIGGER, GnomePieTriggerClass))

typedef struct _GnomePieTrigger GnomePieTrigger;
typedef struct _GnomePieTriggerClass GnomePieTriggerClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GNOME_PIE_TYPE_ACTION (gnome_pie_action_get_type ())
#define GNOME_PIE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ACTION, GnomePieAction))
#define GNOME_PIE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ACTION, GnomePieActionClass))
#define GNOME_PIE_IS_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ACTION))
#define GNOME_PIE_IS_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ACTION))
#define GNOME_PIE_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ACTION, GnomePieActionClass))

typedef struct _GnomePieAction GnomePieAction;
typedef struct _GnomePieActionClass GnomePieActionClass;

#define GNOME_PIE_TYPE_KEY_ACTION (gnome_pie_key_action_get_type ())
#define GNOME_PIE_KEY_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_KEY_ACTION, GnomePieKeyAction))
#define GNOME_PIE_KEY_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_KEY_ACTION, GnomePieKeyActionClass))
#define GNOME_PIE_IS_KEY_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_KEY_ACTION))
#define GNOME_PIE_IS_KEY_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_KEY_ACTION))
#define GNOME_PIE_KEY_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_KEY_ACTION, GnomePieKeyActionClass))

typedef struct _GnomePieKeyAction GnomePieKeyAction;
typedef struct _GnomePieKeyActionClass GnomePieKeyActionClass;

#define GNOME_PIE_TYPE_ACTION_GROUP (gnome_pie_action_group_get_type ())
#define GNOME_PIE_ACTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroup))
#define GNOME_PIE_ACTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroupClass))
#define GNOME_PIE_IS_ACTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ACTION_GROUP))
#define GNOME_PIE_IS_ACTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ACTION_GROUP))
#define GNOME_PIE_ACTION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroupClass))

typedef struct _GnomePieActionGroup GnomePieActionGroup;
typedef struct _GnomePieActionGroupClass GnomePieActionGroupClass;

#define GNOME_PIE_TYPE_BOOKMARK_GROUP (gnome_pie_bookmark_group_get_type ())
#define GNOME_PIE_BOOKMARK_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_BOOKMARK_GROUP, GnomePieBookmarkGroup))
#define GNOME_PIE_BOOKMARK_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_BOOKMARK_GROUP, GnomePieBookmarkGroupClass))
#define GNOME_PIE_IS_BOOKMARK_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_BOOKMARK_GROUP))
#define GNOME_PIE_IS_BOOKMARK_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_BOOKMARK_GROUP))
#define GNOME_PIE_BOOKMARK_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_BOOKMARK_GROUP, GnomePieBookmarkGroupClass))

typedef struct _GnomePieBookmarkGroup GnomePieBookmarkGroup;
typedef struct _GnomePieBookmarkGroupClass GnomePieBookmarkGroupClass;

#define GNOME_PIE_TYPE_DEVICES_GROUP (gnome_pie_devices_group_get_type ())
#define GNOME_PIE_DEVICES_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroup))
#define GNOME_PIE_DEVICES_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroupClass))
#define GNOME_PIE_IS_DEVICES_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_DEVICES_GROUP))
#define GNOME_PIE_IS_DEVICES_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_DEVICES_GROUP))
#define GNOME_PIE_DEVICES_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroupClass))

typedef struct _GnomePieDevicesGroup GnomePieDevicesGroup;
typedef struct _GnomePieDevicesGroupClass GnomePieDevicesGroupClass;

#define GNOME_PIE_TYPE_SESSION_GROUP (gnome_pie_session_group_get_type ())
#define GNOME_PIE_SESSION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_SESSION_GROUP, GnomePieSessionGroup))
#define GNOME_PIE_SESSION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_SESSION_GROUP, GnomePieSessionGroupClass))
#define GNOME_PIE_IS_SESSION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_SESSION_GROUP))
#define GNOME_PIE_IS_SESSION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_SESSION_GROUP))
#define GNOME_PIE_SESSION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_SESSION_GROUP, GnomePieSessionGroupClass))

typedef struct _GnomePieSessionGroup GnomePieSessionGroup;
typedef struct _GnomePieSessionGroupClass GnomePieSessionGroupClass;

#define GNOME_PIE_TYPE_MENU_GROUP (gnome_pie_menu_group_get_type ())
#define GNOME_PIE_MENU_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_MENU_GROUP, GnomePieMenuGroup))
#define GNOME_PIE_MENU_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_MENU_GROUP, GnomePieMenuGroupClass))
#define GNOME_PIE_IS_MENU_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_MENU_GROUP))
#define GNOME_PIE_IS_MENU_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_MENU_GROUP))
#define GNOME_PIE_MENU_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_MENU_GROUP, GnomePieMenuGroupClass))

typedef struct _GnomePieMenuGroup GnomePieMenuGroup;
typedef struct _GnomePieMenuGroupClass GnomePieMenuGroupClass;

#define GNOME_PIE_TYPE_WINDOW_LIST_GROUP (gnome_pie_window_list_group_get_type ())
#define GNOME_PIE_WINDOW_LIST_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_WINDOW_LIST_GROUP, GnomePieWindowListGroup))
#define GNOME_PIE_WINDOW_LIST_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_WINDOW_LIST_GROUP, GnomePieWindowListGroupClass))
#define GNOME_PIE_IS_WINDOW_LIST_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_WINDOW_LIST_GROUP))
#define GNOME_PIE_IS_WINDOW_LIST_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_WINDOW_LIST_GROUP))
#define GNOME_PIE_WINDOW_LIST_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_WINDOW_LIST_GROUP, GnomePieWindowListGroupClass))

typedef struct _GnomePieWindowListGroup GnomePieWindowListGroup;
typedef struct _GnomePieWindowListGroupClass GnomePieWindowListGroupClass;

VALA_EXTERN void gnome_pie_pies_create_default_config (void);
VALA_EXTERN GType gnome_pie_pie_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePiePie, g_object_unref)
VALA_EXTERN GType gnome_pie_trigger_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieTrigger, g_object_unref)
VALA_EXTERN GnomePiePie* gnome_pie_pie_manager_create_persistent_pie (const gchar* name,
                                                          const gchar* icon_name,
                                                          GnomePieTrigger* hotkey,
                                                          const gchar* desired_id);
VALA_EXTERN GnomePieTrigger* gnome_pie_trigger_new_from_string (const gchar* trigger);
VALA_EXTERN GnomePieTrigger* gnome_pie_trigger_construct_from_string (GType object_type,
                                                          const gchar* trigger);
VALA_EXTERN GType gnome_pie_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieAction, g_object_unref)
VALA_EXTERN void gnome_pie_pie_add_action (GnomePiePie* self,
                               GnomePieAction* action,
                               gint at_position);
VALA_EXTERN GnomePieKeyAction* gnome_pie_key_action_new (const gchar* name,
                                             const gchar* icon,
                                             const gchar* command,
                                             gboolean is_quickaction);
VALA_EXTERN GnomePieKeyAction* gnome_pie_key_action_construct (GType object_type,
                                                   const gchar* name,
                                                   const gchar* icon,
                                                   const gchar* command,
                                                   gboolean is_quickaction);
VALA_EXTERN GType gnome_pie_key_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieKeyAction, g_object_unref)
VALA_EXTERN GnomePieAction* gnome_pie_action_registry_default_for_mime_type (const gchar* type);
VALA_EXTERN GnomePieAction* gnome_pie_action_registry_default_for_uri (const gchar* uri);
VALA_EXTERN GType gnome_pie_action_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieActionGroup, g_object_unref)
VALA_EXTERN void gnome_pie_pie_add_group (GnomePiePie* self,
                              GnomePieActionGroup* group,
                              gint at_position);
VALA_EXTERN const gchar* gnome_pie_pie_get_id (GnomePiePie* self);
VALA_EXTERN GnomePieBookmarkGroup* gnome_pie_bookmark_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieBookmarkGroup* gnome_pie_bookmark_group_construct (GType object_type,
                                                           const gchar* parent_id);
VALA_EXTERN GType gnome_pie_bookmark_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieBookmarkGroup, g_object_unref)
VALA_EXTERN GnomePieDevicesGroup* gnome_pie_devices_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieDevicesGroup* gnome_pie_devices_group_construct (GType object_type,
                                                         const gchar* parent_id);
VALA_EXTERN GType gnome_pie_devices_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieDevicesGroup, g_object_unref)
VALA_EXTERN GnomePieSessionGroup* gnome_pie_session_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieSessionGroup* gnome_pie_session_group_construct (GType object_type,
                                                         const gchar* parent_id);
VALA_EXTERN GType gnome_pie_session_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieSessionGroup, g_object_unref)
VALA_EXTERN GnomePieMenuGroup* gnome_pie_menu_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieMenuGroup* gnome_pie_menu_group_construct (GType object_type,
                                                   const gchar* parent_id);
VALA_EXTERN GType gnome_pie_menu_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieMenuGroup, g_object_unref)
VALA_EXTERN GnomePieWindowListGroup* gnome_pie_window_list_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieWindowListGroup* gnome_pie_window_list_group_construct (GType object_type,
                                                                const gchar* parent_id);
VALA_EXTERN GType gnome_pie_window_list_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieWindowListGroup, g_object_unref)
VALA_EXTERN void gnome_pie_pies_save (void);

void
gnome_pie_pies_create_default_config (void)
{
	GnomePiePie* multimedia = NULL;
	GnomePieTrigger* _tmp0_;
	GnomePieTrigger* _tmp1_;
	GnomePiePie* _tmp2_;
	GnomePiePie* _tmp3_;
	GnomePiePie* _tmp4_;
	GnomePieKeyAction* _tmp5_;
	GnomePieKeyAction* _tmp6_;
	GnomePiePie* _tmp7_;
	GnomePieKeyAction* _tmp8_;
	GnomePieKeyAction* _tmp9_;
	GnomePiePie* _tmp10_;
	GnomePieKeyAction* _tmp11_;
	GnomePieKeyAction* _tmp12_;
	GnomePiePie* _tmp13_;
	GnomePieKeyAction* _tmp14_;
	GnomePieKeyAction* _tmp15_;
	GnomePiePie* apps = NULL;
	GnomePieTrigger* _tmp16_;
	GnomePieTrigger* _tmp17_;
	GnomePiePie* _tmp18_;
	GnomePiePie* _tmp19_;
	GnomePiePie* _tmp20_;
	GnomePieAction* _tmp21_;
	GnomePieAction* _tmp22_;
	GnomePiePie* _tmp23_;
	GnomePieAction* _tmp24_;
	GnomePieAction* _tmp25_;
	GnomePiePie* _tmp26_;
	GnomePieAction* _tmp27_;
	GnomePieAction* _tmp28_;
	GnomePiePie* _tmp29_;
	GnomePieAction* _tmp30_;
	GnomePieAction* _tmp31_;
	GnomePiePie* _tmp32_;
	GnomePieAction* _tmp33_;
	GnomePieAction* _tmp34_;
	GnomePiePie* _tmp35_;
	GnomePieAction* _tmp36_;
	GnomePieAction* _tmp37_;
	GnomePiePie* bookmarks = NULL;
	GnomePieTrigger* _tmp38_;
	GnomePieTrigger* _tmp39_;
	GnomePiePie* _tmp40_;
	GnomePiePie* _tmp41_;
	GnomePiePie* _tmp42_;
	GnomePiePie* _tmp43_;
	const gchar* _tmp44_;
	const gchar* _tmp45_;
	GnomePieBookmarkGroup* _tmp46_;
	GnomePieBookmarkGroup* _tmp47_;
	GnomePiePie* _tmp48_;
	GnomePiePie* _tmp49_;
	const gchar* _tmp50_;
	const gchar* _tmp51_;
	GnomePieDevicesGroup* _tmp52_;
	GnomePieDevicesGroup* _tmp53_;
	GnomePiePie* session = NULL;
	GnomePieTrigger* _tmp54_;
	GnomePieTrigger* _tmp55_;
	GnomePiePie* _tmp56_;
	GnomePiePie* _tmp57_;
	GnomePiePie* _tmp58_;
	GnomePiePie* _tmp59_;
	const gchar* _tmp60_;
	const gchar* _tmp61_;
	GnomePieSessionGroup* _tmp62_;
	GnomePieSessionGroup* _tmp63_;
	GnomePiePie* menu = NULL;
	GnomePieTrigger* _tmp64_;
	GnomePieTrigger* _tmp65_;
	GnomePiePie* _tmp66_;
	GnomePiePie* _tmp67_;
	GnomePiePie* _tmp68_;
	GnomePiePie* _tmp69_;
	const gchar* _tmp70_;
	const gchar* _tmp71_;
	GnomePieMenuGroup* _tmp72_;
	GnomePieMenuGroup* _tmp73_;
	GnomePiePie* window = NULL;
	GnomePieTrigger* _tmp74_;
	GnomePieTrigger* _tmp75_;
	GnomePiePie* _tmp76_;
	GnomePiePie* _tmp77_;
	GnomePiePie* _tmp78_;
	GnomePieKeyAction* _tmp79_;
	GnomePieKeyAction* _tmp80_;
	GnomePiePie* _tmp81_;
	GnomePieKeyAction* _tmp82_;
	GnomePieKeyAction* _tmp83_;
	GnomePiePie* _tmp84_;
	GnomePieKeyAction* _tmp85_;
	GnomePieKeyAction* _tmp86_;
	GnomePiePie* _tmp87_;
	GnomePieKeyAction* _tmp88_;
	GnomePieKeyAction* _tmp89_;
	GnomePiePie* _tmp90_;
	GnomePieKeyAction* _tmp91_;
	GnomePieKeyAction* _tmp92_;
	const gchar* _tmp93_;
	_tmp0_ = gnome_pie_trigger_new_from_string ("<Control><Alt>m");
	_tmp1_ = _tmp0_;
	_tmp2_ = gnome_pie_pie_manager_create_persistent_pie (_ ("Multimedia"), "media-playback-start", _tmp1_, NULL);
	_tmp3_ = _tmp2_;
	_g_object_unref0 (_tmp1_);
	multimedia = _tmp3_;
	_tmp4_ = multimedia;
	_tmp5_ = gnome_pie_key_action_new (_ ("Next Track"), "media-skip-forward", "XF86AudioNext", TRUE);
	_tmp6_ = _tmp5_;
	gnome_pie_pie_add_action (_tmp4_, (GnomePieAction*) _tmp6_, -1);
	_g_object_unref0 (_tmp6_);
	_tmp7_ = multimedia;
	_tmp8_ = gnome_pie_key_action_new (_ ("Stop"), "media-playback-stop", "XF86AudioStop", FALSE);
	_tmp9_ = _tmp8_;
	gnome_pie_pie_add_action (_tmp7_, (GnomePieAction*) _tmp9_, -1);
	_g_object_unref0 (_tmp9_);
	_tmp10_ = multimedia;
	_tmp11_ = gnome_pie_key_action_new (_ ("Previous Track"), "media-skip-backward", "XF86AudioPrev", FALSE);
	_tmp12_ = _tmp11_;
	gnome_pie_pie_add_action (_tmp10_, (GnomePieAction*) _tmp12_, -1);
	_g_object_unref0 (_tmp12_);
	_tmp13_ = multimedia;
	_tmp14_ = gnome_pie_key_action_new (_ ("Play/Pause"), "media-playback-start", "XF86AudioPlay", FALSE);
	_tmp15_ = _tmp14_;
	gnome_pie_pie_add_action (_tmp13_, (GnomePieAction*) _tmp15_, -1);
	_g_object_unref0 (_tmp15_);
	_tmp16_ = gnome_pie_trigger_new_from_string ("<Control><Alt>a");
	_tmp17_ = _tmp16_;
	_tmp18_ = gnome_pie_pie_manager_create_persistent_pie (_ ("Applications"), "applications-accessories", _tmp17_, NULL);
	_tmp19_ = _tmp18_;
	_g_object_unref0 (_tmp17_);
	apps = _tmp19_;
	_tmp20_ = apps;
	_tmp21_ = gnome_pie_action_registry_default_for_mime_type ("text/plain");
	_tmp22_ = _tmp21_;
	gnome_pie_pie_add_action (_tmp20_, _tmp22_, -1);
	_g_object_unref0 (_tmp22_);
	_tmp23_ = apps;
	_tmp24_ = gnome_pie_action_registry_default_for_mime_type ("audio/ogg");
	_tmp25_ = _tmp24_;
	gnome_pie_pie_add_action (_tmp23_, _tmp25_, -1);
	_g_object_unref0 (_tmp25_);
	_tmp26_ = apps;
	_tmp27_ = gnome_pie_action_registry_default_for_mime_type ("video/ogg");
	_tmp28_ = _tmp27_;
	gnome_pie_pie_add_action (_tmp26_, _tmp28_, -1);
	_g_object_unref0 (_tmp28_);
	_tmp29_ = apps;
	_tmp30_ = gnome_pie_action_registry_default_for_mime_type ("image/jpg");
	_tmp31_ = _tmp30_;
	gnome_pie_pie_add_action (_tmp29_, _tmp31_, -1);
	_g_object_unref0 (_tmp31_);
	_tmp32_ = apps;
	_tmp33_ = gnome_pie_action_registry_default_for_uri ("http");
	_tmp34_ = _tmp33_;
	gnome_pie_pie_add_action (_tmp32_, _tmp34_, -1);
	_g_object_unref0 (_tmp34_);
	_tmp35_ = apps;
	_tmp36_ = gnome_pie_action_registry_default_for_uri ("mailto");
	_tmp37_ = _tmp36_;
	gnome_pie_pie_add_action (_tmp35_, _tmp37_, -1);
	_g_object_unref0 (_tmp37_);
	_tmp38_ = gnome_pie_trigger_new_from_string ("<Control><Alt>b");
	_tmp39_ = _tmp38_;
	_tmp40_ = gnome_pie_pie_manager_create_persistent_pie (_ ("Bookmarks"), "user-bookmarks", _tmp39_, NULL);
	_tmp41_ = _tmp40_;
	_g_object_unref0 (_tmp39_);
	bookmarks = _tmp41_;
	_tmp42_ = bookmarks;
	_tmp43_ = bookmarks;
	_tmp44_ = gnome_pie_pie_get_id (_tmp43_);
	_tmp45_ = _tmp44_;
	_tmp46_ = gnome_pie_bookmark_group_new (_tmp45_);
	_tmp47_ = _tmp46_;
	gnome_pie_pie_add_group (_tmp42_, (GnomePieActionGroup*) _tmp47_, -1);
	_g_object_unref0 (_tmp47_);
	_tmp48_ = bookmarks;
	_tmp49_ = bookmarks;
	_tmp50_ = gnome_pie_pie_get_id (_tmp49_);
	_tmp51_ = _tmp50_;
	_tmp52_ = gnome_pie_devices_group_new (_tmp51_);
	_tmp53_ = _tmp52_;
	gnome_pie_pie_add_group (_tmp48_, (GnomePieActionGroup*) _tmp53_, -1);
	_g_object_unref0 (_tmp53_);
	_tmp54_ = gnome_pie_trigger_new_from_string ("<Control><Alt>q");
	_tmp55_ = _tmp54_;
	_tmp56_ = gnome_pie_pie_manager_create_persistent_pie (_ ("Session"), "system-log-out", _tmp55_, NULL);
	_tmp57_ = _tmp56_;
	_g_object_unref0 (_tmp55_);
	session = _tmp57_;
	_tmp58_ = session;
	_tmp59_ = session;
	_tmp60_ = gnome_pie_pie_get_id (_tmp59_);
	_tmp61_ = _tmp60_;
	_tmp62_ = gnome_pie_session_group_new (_tmp61_);
	_tmp63_ = _tmp62_;
	gnome_pie_pie_add_group (_tmp58_, (GnomePieActionGroup*) _tmp63_, -1);
	_g_object_unref0 (_tmp63_);
	_tmp64_ = gnome_pie_trigger_new_from_string ("<Control><Alt>space");
	_tmp65_ = _tmp64_;
	_tmp66_ = gnome_pie_pie_manager_create_persistent_pie (_ ("Main Menu"), "start-here", _tmp65_, NULL);
	_tmp67_ = _tmp66_;
	_g_object_unref0 (_tmp65_);
	menu = _tmp67_;
	_tmp68_ = menu;
	_tmp69_ = menu;
	_tmp70_ = gnome_pie_pie_get_id (_tmp69_);
	_tmp71_ = _tmp70_;
	_tmp72_ = gnome_pie_menu_group_new (_tmp71_);
	_tmp73_ = _tmp72_;
	gnome_pie_pie_add_group (_tmp68_, (GnomePieActionGroup*) _tmp73_, -1);
	_g_object_unref0 (_tmp73_);
	_tmp74_ = gnome_pie_trigger_new_from_string ("<Control><Alt>w");
	_tmp75_ = _tmp74_;
	_tmp76_ = gnome_pie_pie_manager_create_persistent_pie (_ ("Window"), "preferences-system-windows", _tmp75_, NULL);
	_tmp77_ = _tmp76_;
	_g_object_unref0 (_tmp75_);
	window = _tmp77_;
	_tmp78_ = window;
	_tmp79_ = gnome_pie_key_action_new (_ ("Scale"), "go-top", "<Control><Alt>s", FALSE);
	_tmp80_ = _tmp79_;
	gnome_pie_pie_add_action (_tmp78_, (GnomePieAction*) _tmp80_, -1);
	_g_object_unref0 (_tmp80_);
	_tmp81_ = window;
	_tmp82_ = gnome_pie_key_action_new (_ ("Minimize"), "go-bottom", "<Alt>F9", TRUE);
	_tmp83_ = _tmp82_;
	gnome_pie_pie_add_action (_tmp81_, (GnomePieAction*) _tmp83_, -1);
	_g_object_unref0 (_tmp83_);
	_tmp84_ = window;
	_tmp85_ = gnome_pie_key_action_new (_ ("Close"), "window-close", "<Alt>F4", FALSE);
	_tmp86_ = _tmp85_;
	gnome_pie_pie_add_action (_tmp84_, (GnomePieAction*) _tmp86_, -1);
	_g_object_unref0 (_tmp86_);
	_tmp87_ = window;
	_tmp88_ = gnome_pie_key_action_new (_ ("Maximize"), "view-fullscreen", "<Alt>F10", FALSE);
	_tmp89_ = _tmp88_;
	gnome_pie_pie_add_action (_tmp87_, (GnomePieAction*) _tmp89_, -1);
	_g_object_unref0 (_tmp89_);
	_tmp90_ = window;
	_tmp91_ = gnome_pie_key_action_new (_ ("Restore"), "view-restore", "<Alt>F5", FALSE);
	_tmp92_ = _tmp91_;
	gnome_pie_pie_add_action (_tmp90_, (GnomePieAction*) _tmp92_, -1);
	_g_object_unref0 (_tmp92_);
	_tmp93_ = g_getenv ("XDG_SESSION_TYPE");
	if (g_strcmp0 (_tmp93_, "wayland") != 0) {
		GnomePiePie* alt_tab = NULL;
		GnomePieTrigger* _tmp94_;
		GnomePieTrigger* _tmp95_;
		GnomePiePie* _tmp96_;
		GnomePiePie* _tmp97_;
		GnomePiePie* _tmp98_;
		GnomePiePie* _tmp99_;
		const gchar* _tmp100_;
		const gchar* _tmp101_;
		GnomePieWindowListGroup* _tmp102_;
		GnomePieWindowListGroup* _tmp103_;
		_tmp94_ = gnome_pie_trigger_new_from_string ("<Control><Alt>T");
		_tmp95_ = _tmp94_;
		_tmp96_ = gnome_pie_pie_manager_create_persistent_pie ("Alt Tab", "preferences-system-windows", _tmp95_, NULL);
		_tmp97_ = _tmp96_;
		_g_object_unref0 (_tmp95_);
		alt_tab = _tmp97_;
		_tmp98_ = alt_tab;
		_tmp99_ = alt_tab;
		_tmp100_ = gnome_pie_pie_get_id (_tmp99_);
		_tmp101_ = _tmp100_;
		_tmp102_ = gnome_pie_window_list_group_new (_tmp101_);
		_tmp103_ = _tmp102_;
		gnome_pie_pie_add_group (_tmp98_, (GnomePieActionGroup*) _tmp103_, -1);
		_g_object_unref0 (_tmp103_);
		_g_object_unref0 (alt_tab);
	}
	gnome_pie_pies_save ();
	_g_object_unref0 (window);
	_g_object_unref0 (menu);
	_g_object_unref0 (session);
	_g_object_unref0 (bookmarks);
	_g_object_unref0 (apps);
	_g_object_unref0 (multimedia);
}

