/* groupRegistry.c generated by valac 0.56.18, the Vala compiler
 * generated from groupRegistry.vala, do not modify */

/*///////////////////////////////////////////////////////////////////////*/
/* Copyright 2011-2021 Simon Schneegans*/
/**/
/* Permission is hereby granted, free of charge, to any person obtaining*/
/* a copy of this software and associated documentation files (the*/
/* "Software"), to deal in the Software without restriction, including*/
/* without limitation the rights to use, copy, modify, merge, publish,*/
/* distribute, sublicense, and/or sell copies of the Software, and to*/
/* permit persons to whom the Software is furnished to do so, subject to*/
/* the following conditions:*/
/* */
/* The above copyright notice and this permission notice shall be*/
/* included in all copies or substantial portions of the Software.*/
/* */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,*/
/* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF*/
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*/
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY*/
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,*/
/* TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE*/
/* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.*/
/*///////////////////////////////////////////////////////////////////////*/

#include <glib-object.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GNOME_PIE_TYPE_GROUP_REGISTRY (gnome_pie_group_registry_get_type ())
#define GNOME_PIE_GROUP_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_GROUP_REGISTRY, GnomePieGroupRegistry))
#define GNOME_PIE_GROUP_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_GROUP_REGISTRY, GnomePieGroupRegistryClass))
#define GNOME_PIE_IS_GROUP_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_GROUP_REGISTRY))
#define GNOME_PIE_IS_GROUP_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_GROUP_REGISTRY))
#define GNOME_PIE_GROUP_REGISTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_GROUP_REGISTRY, GnomePieGroupRegistryClass))

typedef struct _GnomePieGroupRegistry GnomePieGroupRegistry;
typedef struct _GnomePieGroupRegistryClass GnomePieGroupRegistryClass;
typedef struct _GnomePieGroupRegistryPrivate GnomePieGroupRegistryPrivate;
enum  {
	GNOME_PIE_GROUP_REGISTRY_0_PROPERTY,
	GNOME_PIE_GROUP_REGISTRY_NUM_PROPERTIES
};
static GParamSpec* gnome_pie_group_registry_properties[GNOME_PIE_GROUP_REGISTRY_NUM_PROPERTIES];

#define GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION (gnome_pie_group_registry_typedescription_get_type ())
#define GNOME_PIE_GROUP_REGISTRY_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieGroupRegistryTypeDescription))
#define GNOME_PIE_GROUP_REGISTRY_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieGroupRegistryTypeDescriptionClass))
#define GNOME_PIE_GROUP_REGISTRY_IS_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_GROUP_REGISTRY_IS_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_GROUP_REGISTRY_TYPEDESCRIPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieGroupRegistryTypeDescriptionClass))

typedef struct _GnomePieGroupRegistryTypeDescription GnomePieGroupRegistryTypeDescription;
typedef struct _GnomePieGroupRegistryTypeDescriptionClass GnomePieGroupRegistryTypeDescriptionClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _gnome_pie_group_registry_typedescription_unref0(var) ((var == NULL) ? NULL : (var = (gnome_pie_group_registry_typedescription_unref (var), NULL)))

#define GNOME_PIE_TYPE_ACTION_GROUP (gnome_pie_action_group_get_type ())
#define GNOME_PIE_ACTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroup))
#define GNOME_PIE_ACTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroupClass))
#define GNOME_PIE_IS_ACTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ACTION_GROUP))
#define GNOME_PIE_IS_ACTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ACTION_GROUP))
#define GNOME_PIE_ACTION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ACTION_GROUP, GnomePieActionGroupClass))

typedef struct _GnomePieActionGroup GnomePieActionGroup;
typedef struct _GnomePieActionGroupClass GnomePieActionGroupClass;

#define GNOME_PIE_TYPE_BOOKMARK_GROUP (gnome_pie_bookmark_group_get_type ())
#define GNOME_PIE_BOOKMARK_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_BOOKMARK_GROUP, GnomePieBookmarkGroup))
#define GNOME_PIE_BOOKMARK_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_BOOKMARK_GROUP, GnomePieBookmarkGroupClass))
#define GNOME_PIE_IS_BOOKMARK_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_BOOKMARK_GROUP))
#define GNOME_PIE_IS_BOOKMARK_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_BOOKMARK_GROUP))
#define GNOME_PIE_BOOKMARK_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_BOOKMARK_GROUP, GnomePieBookmarkGroupClass))

typedef struct _GnomePieBookmarkGroup GnomePieBookmarkGroup;
typedef struct _GnomePieBookmarkGroupClass GnomePieBookmarkGroupClass;

#define GNOME_PIE_TYPE_CLIPBOARD_GROUP (gnome_pie_clipboard_group_get_type ())
#define GNOME_PIE_CLIPBOARD_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_CLIPBOARD_GROUP, GnomePieClipboardGroup))
#define GNOME_PIE_CLIPBOARD_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_CLIPBOARD_GROUP, GnomePieClipboardGroupClass))
#define GNOME_PIE_IS_CLIPBOARD_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_CLIPBOARD_GROUP))
#define GNOME_PIE_IS_CLIPBOARD_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_CLIPBOARD_GROUP))
#define GNOME_PIE_CLIPBOARD_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_CLIPBOARD_GROUP, GnomePieClipboardGroupClass))

typedef struct _GnomePieClipboardGroup GnomePieClipboardGroup;
typedef struct _GnomePieClipboardGroupClass GnomePieClipboardGroupClass;

#define GNOME_PIE_TYPE_DEVICES_GROUP (gnome_pie_devices_group_get_type ())
#define GNOME_PIE_DEVICES_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroup))
#define GNOME_PIE_DEVICES_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroupClass))
#define GNOME_PIE_IS_DEVICES_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_DEVICES_GROUP))
#define GNOME_PIE_IS_DEVICES_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_DEVICES_GROUP))
#define GNOME_PIE_DEVICES_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_DEVICES_GROUP, GnomePieDevicesGroupClass))

typedef struct _GnomePieDevicesGroup GnomePieDevicesGroup;
typedef struct _GnomePieDevicesGroupClass GnomePieDevicesGroupClass;

#define GNOME_PIE_TYPE_MENU_GROUP (gnome_pie_menu_group_get_type ())
#define GNOME_PIE_MENU_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_MENU_GROUP, GnomePieMenuGroup))
#define GNOME_PIE_MENU_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_MENU_GROUP, GnomePieMenuGroupClass))
#define GNOME_PIE_IS_MENU_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_MENU_GROUP))
#define GNOME_PIE_IS_MENU_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_MENU_GROUP))
#define GNOME_PIE_MENU_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_MENU_GROUP, GnomePieMenuGroupClass))

typedef struct _GnomePieMenuGroup GnomePieMenuGroup;
typedef struct _GnomePieMenuGroupClass GnomePieMenuGroupClass;

#define GNOME_PIE_TYPE_SESSION_GROUP (gnome_pie_session_group_get_type ())
#define GNOME_PIE_SESSION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_SESSION_GROUP, GnomePieSessionGroup))
#define GNOME_PIE_SESSION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_SESSION_GROUP, GnomePieSessionGroupClass))
#define GNOME_PIE_IS_SESSION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_SESSION_GROUP))
#define GNOME_PIE_IS_SESSION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_SESSION_GROUP))
#define GNOME_PIE_SESSION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_SESSION_GROUP, GnomePieSessionGroupClass))

typedef struct _GnomePieSessionGroup GnomePieSessionGroup;
typedef struct _GnomePieSessionGroupClass GnomePieSessionGroupClass;

#define GNOME_PIE_TYPE_WINDOW_LIST_GROUP (gnome_pie_window_list_group_get_type ())
#define GNOME_PIE_WINDOW_LIST_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_WINDOW_LIST_GROUP, GnomePieWindowListGroup))
#define GNOME_PIE_WINDOW_LIST_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_WINDOW_LIST_GROUP, GnomePieWindowListGroupClass))
#define GNOME_PIE_IS_WINDOW_LIST_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_WINDOW_LIST_GROUP))
#define GNOME_PIE_IS_WINDOW_LIST_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_WINDOW_LIST_GROUP))
#define GNOME_PIE_WINDOW_LIST_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_WINDOW_LIST_GROUP, GnomePieWindowListGroupClass))

typedef struct _GnomePieWindowListGroup GnomePieWindowListGroup;
typedef struct _GnomePieWindowListGroupClass GnomePieWindowListGroupClass;
typedef struct _GnomePieGroupRegistryTypeDescriptionPrivate GnomePieGroupRegistryTypeDescriptionPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _GnomePieGroupRegistryParamSpecTypeDescription GnomePieGroupRegistryParamSpecTypeDescription;

struct _GnomePieGroupRegistry {
	GObject parent_instance;
	GnomePieGroupRegistryPrivate * priv;
};

struct _GnomePieGroupRegistryClass {
	GObjectClass parent_class;
};

struct _GnomePieGroupRegistryTypeDescription {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GnomePieGroupRegistryTypeDescriptionPrivate * priv;
};

struct _GnomePieGroupRegistryTypeDescriptionClass {
	GTypeClass parent_class;
	void (*finalize) (GnomePieGroupRegistryTypeDescription *self);
};

struct _GnomePieGroupRegistryTypeDescriptionPrivate {
	gchar* _name;
	gchar* _icon;
	gchar* _description;
	gchar* _id;
};

struct _GnomePieGroupRegistryParamSpecTypeDescription {
	GParamSpec parent_instance;
};

static gpointer gnome_pie_group_registry_parent_class = NULL;
static GeeArrayList* gnome_pie_group_registry__types;
static GeeArrayList* gnome_pie_group_registry__types = NULL;
static GeeHashMap* gnome_pie_group_registry__descriptions;
static GeeHashMap* gnome_pie_group_registry__descriptions = NULL;
static gint GnomePieGroupRegistryTypeDescription_private_offset;
static gpointer gnome_pie_group_registry_typedescription_parent_class = NULL;

VALA_EXTERN GType gnome_pie_group_registry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieGroupRegistry, g_object_unref)
VALA_EXTERN gpointer gnome_pie_group_registry_typedescription_ref (gpointer instance);
VALA_EXTERN void gnome_pie_group_registry_typedescription_unref (gpointer instance);
VALA_EXTERN GParamSpec* gnome_pie_group_registry_param_spec_typedescription (const gchar* name,
                                                                 const gchar* nick,
                                                                 const gchar* blurb,
                                                                 GType object_type,
                                                                 GParamFlags flags);
VALA_EXTERN void gnome_pie_group_registry_value_set_typedescription (GValue* value,
                                                         gpointer v_object);
VALA_EXTERN void gnome_pie_group_registry_value_take_typedescription (GValue* value,
                                                          gpointer v_object);
VALA_EXTERN gpointer gnome_pie_group_registry_value_get_typedescription (const GValue* value);
VALA_EXTERN GType gnome_pie_group_registry_typedescription_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieGroupRegistryTypeDescription, gnome_pie_group_registry_typedescription_unref)
VALA_EXTERN void gnome_pie_group_registry_init (void);
static void gnome_pie_group_registry_set_types (GeeArrayList* value);
static void gnome_pie_group_registry_set_descriptions (GeeHashMap* value);
VALA_EXTERN GnomePieGroupRegistryTypeDescription* gnome_pie_bookmark_group_register (void);
VALA_EXTERN GeeArrayList* gnome_pie_group_registry_get_types (void);
VALA_EXTERN GType gnome_pie_action_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieActionGroup, g_object_unref)
VALA_EXTERN GType gnome_pie_bookmark_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieBookmarkGroup, g_object_unref)
VALA_EXTERN GeeHashMap* gnome_pie_group_registry_get_descriptions (void);
VALA_EXTERN GnomePieGroupRegistryTypeDescription* gnome_pie_clipboard_group_register (void);
VALA_EXTERN GType gnome_pie_clipboard_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieClipboardGroup, g_object_unref)
VALA_EXTERN GnomePieGroupRegistryTypeDescription* gnome_pie_devices_group_register (void);
VALA_EXTERN GType gnome_pie_devices_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieDevicesGroup, g_object_unref)
VALA_EXTERN GnomePieGroupRegistryTypeDescription* gnome_pie_menu_group_register (void);
VALA_EXTERN GType gnome_pie_menu_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieMenuGroup, g_object_unref)
VALA_EXTERN GnomePieGroupRegistryTypeDescription* gnome_pie_session_group_register (void);
VALA_EXTERN GType gnome_pie_session_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieSessionGroup, g_object_unref)
VALA_EXTERN GnomePieGroupRegistryTypeDescription* gnome_pie_window_list_group_register (void);
VALA_EXTERN GType gnome_pie_window_list_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieWindowListGroup, g_object_unref)
VALA_EXTERN GnomePieActionGroup* gnome_pie_group_registry_create_group (const gchar* type_id,
                                                            const gchar* parent_id);
VALA_EXTERN GnomePieBookmarkGroup* gnome_pie_bookmark_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieBookmarkGroup* gnome_pie_bookmark_group_construct (GType object_type,
                                                           const gchar* parent_id);
VALA_EXTERN GnomePieClipboardGroup* gnome_pie_clipboard_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieClipboardGroup* gnome_pie_clipboard_group_construct (GType object_type,
                                                             const gchar* parent_id);
VALA_EXTERN GnomePieDevicesGroup* gnome_pie_devices_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieDevicesGroup* gnome_pie_devices_group_construct (GType object_type,
                                                         const gchar* parent_id);
VALA_EXTERN GnomePieMenuGroup* gnome_pie_menu_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieMenuGroup* gnome_pie_menu_group_construct (GType object_type,
                                                   const gchar* parent_id);
VALA_EXTERN GnomePieSessionGroup* gnome_pie_session_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieSessionGroup* gnome_pie_session_group_construct (GType object_type,
                                                         const gchar* parent_id);
VALA_EXTERN GnomePieWindowListGroup* gnome_pie_window_list_group_new (const gchar* parent_id);
VALA_EXTERN GnomePieWindowListGroup* gnome_pie_window_list_group_construct (GType object_type,
                                                                const gchar* parent_id);
VALA_EXTERN void gnome_pie_window_list_group_set_current_workspace_only (GnomePieWindowListGroup* self,
                                                             gboolean value);
VALA_EXTERN GnomePieGroupRegistry* gnome_pie_group_registry_new (void);
VALA_EXTERN GnomePieGroupRegistry* gnome_pie_group_registry_construct (GType object_type);
VALA_EXTERN GnomePieGroupRegistryTypeDescription* gnome_pie_group_registry_typedescription_new (void);
VALA_EXTERN GnomePieGroupRegistryTypeDescription* gnome_pie_group_registry_typedescription_construct (GType object_type);
VALA_EXTERN const gchar* gnome_pie_group_registry_typedescription_get_name (GnomePieGroupRegistryTypeDescription* self);
VALA_EXTERN void gnome_pie_group_registry_typedescription_set_name (GnomePieGroupRegistryTypeDescription* self,
                                                        const gchar* value);
VALA_EXTERN const gchar* gnome_pie_group_registry_typedescription_get_icon (GnomePieGroupRegistryTypeDescription* self);
VALA_EXTERN void gnome_pie_group_registry_typedescription_set_icon (GnomePieGroupRegistryTypeDescription* self,
                                                        const gchar* value);
VALA_EXTERN const gchar* gnome_pie_group_registry_typedescription_get_description (GnomePieGroupRegistryTypeDescription* self);
VALA_EXTERN void gnome_pie_group_registry_typedescription_set_description (GnomePieGroupRegistryTypeDescription* self,
                                                               const gchar* value);
VALA_EXTERN const gchar* gnome_pie_group_registry_typedescription_get_id (GnomePieGroupRegistryTypeDescription* self);
VALA_EXTERN void gnome_pie_group_registry_typedescription_set_id (GnomePieGroupRegistryTypeDescription* self,
                                                      const gchar* value);
static void gnome_pie_group_registry_typedescription_finalize (GnomePieGroupRegistryTypeDescription * obj);
static GType gnome_pie_group_registry_typedescription_get_type_once (void);
static void gnome_pie_group_registry_finalize (GObject * obj);
static GType gnome_pie_group_registry_get_type_once (void);
static void _vala_gnome_pie_group_registry_get_property (GObject * object,
                                                  guint property_id,
                                                  GValue * value,
                                                  GParamSpec * pspec);
static void _vala_gnome_pie_group_registry_set_property (GObject * object,
                                                  guint property_id,
                                                  const GValue * value,
                                                  GParamSpec * pspec);

void
gnome_pie_group_registry_init (void)
{
	GeeArrayList* _tmp0_;
	GeeArrayList* _tmp1_;
	GeeHashMap* _tmp2_;
	GeeHashMap* _tmp3_;
	GnomePieGroupRegistryTypeDescription* type_description = NULL;
	GnomePieGroupRegistryTypeDescription* _tmp4_;
	GnomePieGroupRegistryTypeDescription* _tmp5_;
	GnomePieGroupRegistryTypeDescription* _tmp13_;
	GnomePieGroupRegistryTypeDescription* _tmp14_;
	GnomePieGroupRegistryTypeDescription* _tmp22_;
	GnomePieGroupRegistryTypeDescription* _tmp23_;
	GnomePieGroupRegistryTypeDescription* _tmp31_;
	GnomePieGroupRegistryTypeDescription* _tmp32_;
	GnomePieGroupRegistryTypeDescription* _tmp40_;
	GnomePieGroupRegistryTypeDescription* _tmp41_;
	GnomePieGroupRegistryTypeDescription* _tmp49_;
	GnomePieGroupRegistryTypeDescription* _tmp50_;
	_tmp0_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL);
	_tmp1_ = _tmp0_;
	gnome_pie_group_registry_set_types (_tmp1_);
	_g_object_unref0 (_tmp1_);
	_tmp2_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, (GBoxedCopyFunc) gnome_pie_group_registry_typedescription_ref, (GDestroyNotify) gnome_pie_group_registry_typedescription_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	_tmp3_ = _tmp2_;
	gnome_pie_group_registry_set_descriptions (_tmp3_);
	_g_object_unref0 (_tmp3_);
	_tmp4_ = gnome_pie_bookmark_group_register ();
	_gnome_pie_group_registry_typedescription_unref0 (type_description);
	type_description = _tmp4_;
	_tmp5_ = type_description;
	if (_tmp5_ != NULL) {
		GeeArrayList* _tmp6_;
		GeeArrayList* _tmp7_;
		const gchar* _tmp8_;
		GeeHashMap* _tmp9_;
		GeeHashMap* _tmp10_;
		const gchar* _tmp11_;
		GnomePieGroupRegistryTypeDescription* _tmp12_;
		_tmp6_ = gnome_pie_group_registry_get_types ();
		_tmp7_ = _tmp6_;
		_tmp8_ = g_type_name (GNOME_PIE_TYPE_BOOKMARK_GROUP);
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp7_, _tmp8_);
		_tmp9_ = gnome_pie_group_registry_get_descriptions ();
		_tmp10_ = _tmp9_;
		_tmp11_ = g_type_name (GNOME_PIE_TYPE_BOOKMARK_GROUP);
		_tmp12_ = type_description;
		gee_abstract_map_set ((GeeAbstractMap*) _tmp10_, _tmp11_, _tmp12_);
	}
	_tmp13_ = gnome_pie_clipboard_group_register ();
	_gnome_pie_group_registry_typedescription_unref0 (type_description);
	type_description = _tmp13_;
	_tmp14_ = type_description;
	if (_tmp14_ != NULL) {
		GeeArrayList* _tmp15_;
		GeeArrayList* _tmp16_;
		const gchar* _tmp17_;
		GeeHashMap* _tmp18_;
		GeeHashMap* _tmp19_;
		const gchar* _tmp20_;
		GnomePieGroupRegistryTypeDescription* _tmp21_;
		_tmp15_ = gnome_pie_group_registry_get_types ();
		_tmp16_ = _tmp15_;
		_tmp17_ = g_type_name (GNOME_PIE_TYPE_CLIPBOARD_GROUP);
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp16_, _tmp17_);
		_tmp18_ = gnome_pie_group_registry_get_descriptions ();
		_tmp19_ = _tmp18_;
		_tmp20_ = g_type_name (GNOME_PIE_TYPE_CLIPBOARD_GROUP);
		_tmp21_ = type_description;
		gee_abstract_map_set ((GeeAbstractMap*) _tmp19_, _tmp20_, _tmp21_);
	}
	_tmp22_ = gnome_pie_devices_group_register ();
	_gnome_pie_group_registry_typedescription_unref0 (type_description);
	type_description = _tmp22_;
	_tmp23_ = type_description;
	if (_tmp23_ != NULL) {
		GeeArrayList* _tmp24_;
		GeeArrayList* _tmp25_;
		const gchar* _tmp26_;
		GeeHashMap* _tmp27_;
		GeeHashMap* _tmp28_;
		const gchar* _tmp29_;
		GnomePieGroupRegistryTypeDescription* _tmp30_;
		_tmp24_ = gnome_pie_group_registry_get_types ();
		_tmp25_ = _tmp24_;
		_tmp26_ = g_type_name (GNOME_PIE_TYPE_DEVICES_GROUP);
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp25_, _tmp26_);
		_tmp27_ = gnome_pie_group_registry_get_descriptions ();
		_tmp28_ = _tmp27_;
		_tmp29_ = g_type_name (GNOME_PIE_TYPE_DEVICES_GROUP);
		_tmp30_ = type_description;
		gee_abstract_map_set ((GeeAbstractMap*) _tmp28_, _tmp29_, _tmp30_);
	}
	_tmp31_ = gnome_pie_menu_group_register ();
	_gnome_pie_group_registry_typedescription_unref0 (type_description);
	type_description = _tmp31_;
	_tmp32_ = type_description;
	if (_tmp32_ != NULL) {
		GeeArrayList* _tmp33_;
		GeeArrayList* _tmp34_;
		const gchar* _tmp35_;
		GeeHashMap* _tmp36_;
		GeeHashMap* _tmp37_;
		const gchar* _tmp38_;
		GnomePieGroupRegistryTypeDescription* _tmp39_;
		_tmp33_ = gnome_pie_group_registry_get_types ();
		_tmp34_ = _tmp33_;
		_tmp35_ = g_type_name (GNOME_PIE_TYPE_MENU_GROUP);
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp34_, _tmp35_);
		_tmp36_ = gnome_pie_group_registry_get_descriptions ();
		_tmp37_ = _tmp36_;
		_tmp38_ = g_type_name (GNOME_PIE_TYPE_MENU_GROUP);
		_tmp39_ = type_description;
		gee_abstract_map_set ((GeeAbstractMap*) _tmp37_, _tmp38_, _tmp39_);
	}
	_tmp40_ = gnome_pie_session_group_register ();
	_gnome_pie_group_registry_typedescription_unref0 (type_description);
	type_description = _tmp40_;
	_tmp41_ = type_description;
	if (_tmp41_ != NULL) {
		GeeArrayList* _tmp42_;
		GeeArrayList* _tmp43_;
		const gchar* _tmp44_;
		GeeHashMap* _tmp45_;
		GeeHashMap* _tmp46_;
		const gchar* _tmp47_;
		GnomePieGroupRegistryTypeDescription* _tmp48_;
		_tmp42_ = gnome_pie_group_registry_get_types ();
		_tmp43_ = _tmp42_;
		_tmp44_ = g_type_name (GNOME_PIE_TYPE_SESSION_GROUP);
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp43_, _tmp44_);
		_tmp45_ = gnome_pie_group_registry_get_descriptions ();
		_tmp46_ = _tmp45_;
		_tmp47_ = g_type_name (GNOME_PIE_TYPE_SESSION_GROUP);
		_tmp48_ = type_description;
		gee_abstract_map_set ((GeeAbstractMap*) _tmp46_, _tmp47_, _tmp48_);
	}
	_tmp49_ = gnome_pie_window_list_group_register ();
	_gnome_pie_group_registry_typedescription_unref0 (type_description);
	type_description = _tmp49_;
	_tmp50_ = type_description;
	if (_tmp50_ != NULL) {
		GeeArrayList* _tmp51_;
		GeeArrayList* _tmp52_;
		const gchar* _tmp53_;
		GeeHashMap* _tmp54_;
		GeeHashMap* _tmp55_;
		const gchar* _tmp56_;
		GnomePieGroupRegistryTypeDescription* _tmp57_;
		_tmp51_ = gnome_pie_group_registry_get_types ();
		_tmp52_ = _tmp51_;
		_tmp53_ = g_type_name (GNOME_PIE_TYPE_WINDOW_LIST_GROUP);
		gee_abstract_collection_add ((GeeAbstractCollection*) _tmp52_, _tmp53_);
		_tmp54_ = gnome_pie_group_registry_get_descriptions ();
		_tmp55_ = _tmp54_;
		_tmp56_ = g_type_name (GNOME_PIE_TYPE_WINDOW_LIST_GROUP);
		_tmp57_ = type_description;
		gee_abstract_map_set ((GeeAbstractMap*) _tmp55_, _tmp56_, _tmp57_);
	}
	_gnome_pie_group_registry_typedescription_unref0 (type_description);
}

GnomePieActionGroup*
gnome_pie_group_registry_create_group (const gchar* type_id,
                                       const gchar* parent_id)
{
	gboolean wayland = FALSE;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GQuark _tmp3_ = 0U;
	static GQuark _tmp2_label0 = 0;
	static GQuark _tmp2_label1 = 0;
	static GQuark _tmp2_label2 = 0;
	static GQuark _tmp2_label3 = 0;
	static GQuark _tmp2_label4 = 0;
	static GQuark _tmp2_label5 = 0;
	static GQuark _tmp2_label6 = 0;
	GnomePieActionGroup* result;
	g_return_val_if_fail (type_id != NULL, NULL);
	g_return_val_if_fail (parent_id != NULL, NULL);
	_tmp0_ = g_getenv ("XDG_SESSION_TYPE");
	wayland = g_strcmp0 (_tmp0_, "wayland") == 0;
	_tmp1_ = type_id;
	_tmp3_ = (NULL == _tmp1_) ? 0 : g_quark_from_string (_tmp1_);
	if (_tmp3_ == ((0 != _tmp2_label0) ? _tmp2_label0 : (_tmp2_label0 = g_quark_from_static_string ("bookmarks")))) {
		switch (0) {
			default:
			{
				GnomePieBookmarkGroup* _tmp4_;
				_tmp4_ = gnome_pie_bookmark_group_new (parent_id);
				result = (GnomePieActionGroup*) _tmp4_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label1) ? _tmp2_label1 : (_tmp2_label1 = g_quark_from_static_string ("clipboard")))) {
		switch (0) {
			default:
			{
				GnomePieClipboardGroup* _tmp5_;
				_tmp5_ = gnome_pie_clipboard_group_new (parent_id);
				result = (GnomePieActionGroup*) _tmp5_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label2) ? _tmp2_label2 : (_tmp2_label2 = g_quark_from_static_string ("devices")))) {
		switch (0) {
			default:
			{
				GnomePieDevicesGroup* _tmp6_;
				_tmp6_ = gnome_pie_devices_group_new (parent_id);
				result = (GnomePieActionGroup*) _tmp6_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label3) ? _tmp2_label3 : (_tmp2_label3 = g_quark_from_static_string ("menu")))) {
		switch (0) {
			default:
			{
				GnomePieMenuGroup* _tmp7_;
				_tmp7_ = gnome_pie_menu_group_new (parent_id);
				result = (GnomePieActionGroup*) _tmp7_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label4) ? _tmp2_label4 : (_tmp2_label4 = g_quark_from_static_string ("session")))) {
		switch (0) {
			default:
			{
				GnomePieSessionGroup* _tmp8_;
				_tmp8_ = gnome_pie_session_group_new (parent_id);
				result = (GnomePieActionGroup*) _tmp8_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label5) ? _tmp2_label5 : (_tmp2_label5 = g_quark_from_static_string ("window_list")))) {
		switch (0) {
			default:
			{
				GnomePieWindowListGroup* _tmp9_;
				if (wayland) {
					result = NULL;
					return result;
				}
				_tmp9_ = gnome_pie_window_list_group_new (parent_id);
				result = (GnomePieActionGroup*) _tmp9_;
				return result;
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label6) ? _tmp2_label6 : (_tmp2_label6 = g_quark_from_static_string ("workspace_window_list")))) {
		switch (0) {
			default:
			{
				GnomePieWindowListGroup* group = NULL;
				GnomePieWindowListGroup* _tmp10_;
				GnomePieWindowListGroup* _tmp11_;
				if (wayland) {
					result = NULL;
					return result;
				}
				_tmp10_ = gnome_pie_window_list_group_new (parent_id);
				group = _tmp10_;
				_tmp11_ = group;
				gnome_pie_window_list_group_set_current_workspace_only (_tmp11_, TRUE);
				result = (GnomePieActionGroup*) group;
				return result;
			}
		}
	}
	result = NULL;
	return result;
}

GnomePieGroupRegistry*
gnome_pie_group_registry_construct (GType object_type)
{
	GnomePieGroupRegistry * self = NULL;
	self = (GnomePieGroupRegistry*) g_object_new (object_type, NULL);
	return self;
}

GnomePieGroupRegistry*
gnome_pie_group_registry_new (void)
{
	return gnome_pie_group_registry_construct (GNOME_PIE_TYPE_GROUP_REGISTRY);
}

GeeArrayList*
gnome_pie_group_registry_get_types (void)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	_tmp0_ = gnome_pie_group_registry__types;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
gnome_pie_group_registry_set_types (GeeArrayList* value)
{
	GeeArrayList* _tmp0_;
	_tmp0_ = _g_object_ref0 (value);
	_g_object_unref0 (gnome_pie_group_registry__types);
	gnome_pie_group_registry__types = _tmp0_;
}

GeeHashMap*
gnome_pie_group_registry_get_descriptions (void)
{
	GeeHashMap* result;
	GeeHashMap* _tmp0_;
	_tmp0_ = gnome_pie_group_registry__descriptions;
	result = _tmp0_;
	return result;
}

static void
gnome_pie_group_registry_set_descriptions (GeeHashMap* value)
{
	GeeHashMap* _tmp0_;
	_tmp0_ = _g_object_ref0 (value);
	_g_object_unref0 (gnome_pie_group_registry__descriptions);
	gnome_pie_group_registry__descriptions = _tmp0_;
}

static inline gpointer
gnome_pie_group_registry_typedescription_get_instance_private (GnomePieGroupRegistryTypeDescription* self)
{
	return G_STRUCT_MEMBER_P (self, GnomePieGroupRegistryTypeDescription_private_offset);
}

GnomePieGroupRegistryTypeDescription*
gnome_pie_group_registry_typedescription_construct (GType object_type)
{
	GnomePieGroupRegistryTypeDescription* self = NULL;
	self = (GnomePieGroupRegistryTypeDescription*) g_type_create_instance (object_type);
	return self;
}

GnomePieGroupRegistryTypeDescription*
gnome_pie_group_registry_typedescription_new (void)
{
	return gnome_pie_group_registry_typedescription_construct (GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION);
}

const gchar*
gnome_pie_group_registry_typedescription_get_name (GnomePieGroupRegistryTypeDescription* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_name;
	result = _tmp0_;
	return result;
}

void
gnome_pie_group_registry_typedescription_set_name (GnomePieGroupRegistryTypeDescription* self,
                                                   const gchar* value)
{
	gchar* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_name);
	self->priv->_name = _tmp0_;
}

const gchar*
gnome_pie_group_registry_typedescription_get_icon (GnomePieGroupRegistryTypeDescription* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_icon;
	result = _tmp0_;
	return result;
}

void
gnome_pie_group_registry_typedescription_set_icon (GnomePieGroupRegistryTypeDescription* self,
                                                   const gchar* value)
{
	gchar* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_icon);
	self->priv->_icon = _tmp0_;
}

const gchar*
gnome_pie_group_registry_typedescription_get_description (GnomePieGroupRegistryTypeDescription* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_description;
	result = _tmp0_;
	return result;
}

void
gnome_pie_group_registry_typedescription_set_description (GnomePieGroupRegistryTypeDescription* self,
                                                          const gchar* value)
{
	gchar* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_description);
	self->priv->_description = _tmp0_;
}

const gchar*
gnome_pie_group_registry_typedescription_get_id (GnomePieGroupRegistryTypeDescription* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
gnome_pie_group_registry_typedescription_set_id (GnomePieGroupRegistryTypeDescription* self,
                                                 const gchar* value)
{
	gchar* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_id);
	self->priv->_id = _tmp0_;
}

static void
gnome_pie_group_registry_value_typedescription_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
gnome_pie_group_registry_value_typedescription_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		gnome_pie_group_registry_typedescription_unref (value->data[0].v_pointer);
	}
}

static void
gnome_pie_group_registry_value_typedescription_copy_value (const GValue* src_value,
                                                           GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = gnome_pie_group_registry_typedescription_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
gnome_pie_group_registry_value_typedescription_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
gnome_pie_group_registry_value_typedescription_collect_value (GValue* value,
                                                              guint n_collect_values,
                                                              GTypeCValue* collect_values,
                                                              guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		GnomePieGroupRegistryTypeDescription * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = gnome_pie_group_registry_typedescription_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
gnome_pie_group_registry_value_typedescription_lcopy_value (const GValue* value,
                                                            guint n_collect_values,
                                                            GTypeCValue* collect_values,
                                                            guint collect_flags)
{
	GnomePieGroupRegistryTypeDescription ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = gnome_pie_group_registry_typedescription_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
gnome_pie_group_registry_param_spec_typedescription (const gchar* name,
                                                     const gchar* nick,
                                                     const gchar* blurb,
                                                     GType object_type,
                                                     GParamFlags flags)
{
	GnomePieGroupRegistryParamSpecTypeDescription* spec;
	g_return_val_if_fail (g_type_is_a (object_type, GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
gnome_pie_group_registry_value_get_typedescription (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION), NULL);
	return value->data[0].v_pointer;
}

void
gnome_pie_group_registry_value_set_typedescription (GValue* value,
                                                    gpointer v_object)
{
	GnomePieGroupRegistryTypeDescription * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		gnome_pie_group_registry_typedescription_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		gnome_pie_group_registry_typedescription_unref (old);
	}
}

void
gnome_pie_group_registry_value_take_typedescription (GValue* value,
                                                     gpointer v_object)
{
	GnomePieGroupRegistryTypeDescription * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		gnome_pie_group_registry_typedescription_unref (old);
	}
}

static void
gnome_pie_group_registry_typedescription_class_init (GnomePieGroupRegistryTypeDescriptionClass * klass,
                                                     gpointer klass_data)
{
	gnome_pie_group_registry_typedescription_parent_class = g_type_class_peek_parent (klass);
	((GnomePieGroupRegistryTypeDescriptionClass *) klass)->finalize = gnome_pie_group_registry_typedescription_finalize;
	g_type_class_adjust_private_offset (klass, &GnomePieGroupRegistryTypeDescription_private_offset);
}

static void
gnome_pie_group_registry_typedescription_instance_init (GnomePieGroupRegistryTypeDescription * self,
                                                        gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	self->priv = gnome_pie_group_registry_typedescription_get_instance_private (self);
	_tmp0_ = g_strdup ("");
	self->priv->_name = _tmp0_;
	_tmp1_ = g_strdup ("");
	self->priv->_icon = _tmp1_;
	_tmp2_ = g_strdup ("");
	self->priv->_description = _tmp2_;
	_tmp3_ = g_strdup ("");
	self->priv->_id = _tmp3_;
	self->ref_count = 1;
}

static void
gnome_pie_group_registry_typedescription_finalize (GnomePieGroupRegistryTypeDescription * obj)
{
	GnomePieGroupRegistryTypeDescription * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_GROUP_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieGroupRegistryTypeDescription);
	g_signal_handlers_destroy (self);
	_g_free0 (self->priv->_name);
	_g_free0 (self->priv->_icon);
	_g_free0 (self->priv->_description);
	_g_free0 (self->priv->_id);
}

static GType
gnome_pie_group_registry_typedescription_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { gnome_pie_group_registry_value_typedescription_init, gnome_pie_group_registry_value_typedescription_free_value, gnome_pie_group_registry_value_typedescription_copy_value, gnome_pie_group_registry_value_typedescription_peek_pointer, "p", gnome_pie_group_registry_value_typedescription_collect_value, "p", gnome_pie_group_registry_value_typedescription_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (GnomePieGroupRegistryTypeDescriptionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gnome_pie_group_registry_typedescription_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GnomePieGroupRegistryTypeDescription), 0, (GInstanceInitFunc) gnome_pie_group_registry_typedescription_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType gnome_pie_group_registry_typedescription_type_id;
	gnome_pie_group_registry_typedescription_type_id = g_type_register_fundamental (g_type_fundamental_next (), "GnomePieGroupRegistryTypeDescription", &g_define_type_info, &g_define_type_fundamental_info, 0);
	GnomePieGroupRegistryTypeDescription_private_offset = g_type_add_instance_private (gnome_pie_group_registry_typedescription_type_id, sizeof (GnomePieGroupRegistryTypeDescriptionPrivate));
	return gnome_pie_group_registry_typedescription_type_id;
}

GType
gnome_pie_group_registry_typedescription_get_type (void)
{
	static volatile gsize gnome_pie_group_registry_typedescription_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_group_registry_typedescription_type_id__once)) {
		GType gnome_pie_group_registry_typedescription_type_id;
		gnome_pie_group_registry_typedescription_type_id = gnome_pie_group_registry_typedescription_get_type_once ();
		g_once_init_leave (&gnome_pie_group_registry_typedescription_type_id__once, gnome_pie_group_registry_typedescription_type_id);
	}
	return gnome_pie_group_registry_typedescription_type_id__once;
}

gpointer
gnome_pie_group_registry_typedescription_ref (gpointer instance)
{
	GnomePieGroupRegistryTypeDescription * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
gnome_pie_group_registry_typedescription_unref (gpointer instance)
{
	GnomePieGroupRegistryTypeDescription * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		GNOME_PIE_GROUP_REGISTRY_TYPEDESCRIPTION_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

static void
gnome_pie_group_registry_class_init (GnomePieGroupRegistryClass * klass,
                                     gpointer klass_data)
{
	gnome_pie_group_registry_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gnome_pie_group_registry_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gnome_pie_group_registry_set_property;
	G_OBJECT_CLASS (klass)->finalize = gnome_pie_group_registry_finalize;
}

static void
gnome_pie_group_registry_instance_init (GnomePieGroupRegistry * self,
                                        gpointer klass)
{
}

static void
gnome_pie_group_registry_finalize (GObject * obj)
{
	GnomePieGroupRegistry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_TYPE_GROUP_REGISTRY, GnomePieGroupRegistry);
	G_OBJECT_CLASS (gnome_pie_group_registry_parent_class)->finalize (obj);
}

static GType
gnome_pie_group_registry_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GnomePieGroupRegistryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gnome_pie_group_registry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GnomePieGroupRegistry), 0, (GInstanceInitFunc) gnome_pie_group_registry_instance_init, NULL };
	GType gnome_pie_group_registry_type_id;
	gnome_pie_group_registry_type_id = g_type_register_static (G_TYPE_OBJECT, "GnomePieGroupRegistry", &g_define_type_info, 0);
	return gnome_pie_group_registry_type_id;
}

GType
gnome_pie_group_registry_get_type (void)
{
	static volatile gsize gnome_pie_group_registry_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_group_registry_type_id__once)) {
		GType gnome_pie_group_registry_type_id;
		gnome_pie_group_registry_type_id = gnome_pie_group_registry_get_type_once ();
		g_once_init_leave (&gnome_pie_group_registry_type_id__once, gnome_pie_group_registry_type_id);
	}
	return gnome_pie_group_registry_type_id__once;
}

static void
_vala_gnome_pie_group_registry_get_property (GObject * object,
                                             guint property_id,
                                             GValue * value,
                                             GParamSpec * pspec)
{
	GnomePieGroupRegistry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GNOME_PIE_TYPE_GROUP_REGISTRY, GnomePieGroupRegistry);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gnome_pie_group_registry_set_property (GObject * object,
                                             guint property_id,
                                             const GValue * value,
                                             GParamSpec * pspec)
{
	GnomePieGroupRegistry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GNOME_PIE_TYPE_GROUP_REGISTRY, GnomePieGroupRegistry);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

