/* actionRegistry.c generated by valac 0.56.18, the Vala compiler
 * generated from actionRegistry.vala, do not modify */

/*///////////////////////////////////////////////////////////////////////*/
/* Copyright 2011-2021 Simon Schneegans*/
/**/
/* Permission is hereby granted, free of charge, to any person obtaining*/
/* a copy of this software and associated documentation files (the*/
/* "Software"), to deal in the Software without restriction, including*/
/* without limitation the rights to use, copy, modify, merge, publish,*/
/* distribute, sublicense, and/or sell copies of the Software, and to*/
/* permit persons to whom the Software is furnished to do so, subject to*/
/* the following conditions:*/
/* */
/* The above copyright notice and this permission notice shall be*/
/* included in all copies or substantial portions of the Software.*/
/* */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,*/
/* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF*/
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*/
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY*/
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,*/
/* TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE*/
/* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.*/
/*///////////////////////////////////////////////////////////////////////*/

#include <glib-object.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <gio/gdesktopappinfo.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GNOME_PIE_TYPE_ACTION_REGISTRY (gnome_pie_action_registry_get_type ())
#define GNOME_PIE_ACTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ACTION_REGISTRY, GnomePieActionRegistry))
#define GNOME_PIE_ACTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ACTION_REGISTRY, GnomePieActionRegistryClass))
#define GNOME_PIE_IS_ACTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ACTION_REGISTRY))
#define GNOME_PIE_IS_ACTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ACTION_REGISTRY))
#define GNOME_PIE_ACTION_REGISTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ACTION_REGISTRY, GnomePieActionRegistryClass))

typedef struct _GnomePieActionRegistry GnomePieActionRegistry;
typedef struct _GnomePieActionRegistryClass GnomePieActionRegistryClass;
typedef struct _GnomePieActionRegistryPrivate GnomePieActionRegistryPrivate;
enum  {
	GNOME_PIE_ACTION_REGISTRY_0_PROPERTY,
	GNOME_PIE_ACTION_REGISTRY_NUM_PROPERTIES
};
static GParamSpec* gnome_pie_action_registry_properties[GNOME_PIE_ACTION_REGISTRY_NUM_PROPERTIES];

#define GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION (gnome_pie_action_registry_typedescription_get_type ())
#define GNOME_PIE_ACTION_REGISTRY_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieActionRegistryTypeDescription))
#define GNOME_PIE_ACTION_REGISTRY_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieActionRegistryTypeDescriptionClass))
#define GNOME_PIE_ACTION_REGISTRY_IS_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_ACTION_REGISTRY_IS_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_ACTION_REGISTRY_TYPEDESCRIPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieActionRegistryTypeDescriptionClass))

typedef struct _GnomePieActionRegistryTypeDescription GnomePieActionRegistryTypeDescription;
typedef struct _GnomePieActionRegistryTypeDescriptionClass GnomePieActionRegistryTypeDescriptionClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GNOME_PIE_TYPE_ACTION (gnome_pie_action_get_type ())
#define GNOME_PIE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ACTION, GnomePieAction))
#define GNOME_PIE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ACTION, GnomePieActionClass))
#define GNOME_PIE_IS_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ACTION))
#define GNOME_PIE_IS_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ACTION))
#define GNOME_PIE_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ACTION, GnomePieActionClass))

typedef struct _GnomePieAction GnomePieAction;
typedef struct _GnomePieActionClass GnomePieActionClass;

#define GNOME_PIE_TYPE_APP_ACTION (gnome_pie_app_action_get_type ())
#define GNOME_PIE_APP_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_APP_ACTION, GnomePieAppAction))
#define GNOME_PIE_APP_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_APP_ACTION, GnomePieAppActionClass))
#define GNOME_PIE_IS_APP_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_APP_ACTION))
#define GNOME_PIE_IS_APP_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_APP_ACTION))
#define GNOME_PIE_APP_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_APP_ACTION, GnomePieAppActionClass))

typedef struct _GnomePieAppAction GnomePieAppAction;
typedef struct _GnomePieAppActionClass GnomePieAppActionClass;
#define _gnome_pie_action_registry_typedescription_unref0(var) ((var == NULL) ? NULL : (var = (gnome_pie_action_registry_typedescription_unref (var), NULL)))

#define GNOME_PIE_TYPE_KEY_ACTION (gnome_pie_key_action_get_type ())
#define GNOME_PIE_KEY_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_KEY_ACTION, GnomePieKeyAction))
#define GNOME_PIE_KEY_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_KEY_ACTION, GnomePieKeyActionClass))
#define GNOME_PIE_IS_KEY_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_KEY_ACTION))
#define GNOME_PIE_IS_KEY_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_KEY_ACTION))
#define GNOME_PIE_KEY_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_KEY_ACTION, GnomePieKeyActionClass))

typedef struct _GnomePieKeyAction GnomePieKeyAction;
typedef struct _GnomePieKeyActionClass GnomePieKeyActionClass;

#define GNOME_PIE_TYPE_PIE_ACTION (gnome_pie_pie_action_get_type ())
#define GNOME_PIE_PIE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_PIE_ACTION, GnomePiePieAction))
#define GNOME_PIE_PIE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_PIE_ACTION, GnomePiePieActionClass))
#define GNOME_PIE_IS_PIE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_PIE_ACTION))
#define GNOME_PIE_IS_PIE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_PIE_ACTION))
#define GNOME_PIE_PIE_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_PIE_ACTION, GnomePiePieActionClass))

typedef struct _GnomePiePieAction GnomePiePieAction;
typedef struct _GnomePiePieActionClass GnomePiePieActionClass;

#define GNOME_PIE_TYPE_URI_ACTION (gnome_pie_uri_action_get_type ())
#define GNOME_PIE_URI_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_URI_ACTION, GnomePieUriAction))
#define GNOME_PIE_URI_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_URI_ACTION, GnomePieUriActionClass))
#define GNOME_PIE_IS_URI_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_URI_ACTION))
#define GNOME_PIE_IS_URI_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_URI_ACTION))
#define GNOME_PIE_URI_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_URI_ACTION, GnomePieUriActionClass))

typedef struct _GnomePieUriAction GnomePieUriAction;
typedef struct _GnomePieUriActionClass GnomePieUriActionClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _GnomePieActionRegistryTypeDescriptionPrivate GnomePieActionRegistryTypeDescriptionPrivate;
typedef struct _GnomePieActionRegistryParamSpecTypeDescription GnomePieActionRegistryParamSpecTypeDescription;

struct _GnomePieActionRegistry {
	GObject parent_instance;
	GnomePieActionRegistryPrivate * priv;
};

struct _GnomePieActionRegistryClass {
	GObjectClass parent_class;
};

struct _GnomePieActionRegistryTypeDescription {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GnomePieActionRegistryTypeDescriptionPrivate * priv;
};

struct _GnomePieActionRegistryTypeDescriptionClass {
	GTypeClass parent_class;
	void (*finalize) (GnomePieActionRegistryTypeDescription *self);
};

struct _GnomePieActionRegistryTypeDescriptionPrivate {
	gchar* _name;
	gchar* _icon;
	gchar* _description;
	gchar* _id;
	gboolean _icon_name_editable;
};

struct _GnomePieActionRegistryParamSpecTypeDescription {
	GParamSpec parent_instance;
};

static gpointer gnome_pie_action_registry_parent_class = NULL;
static GeeArrayList* gnome_pie_action_registry__types;
static GeeArrayList* gnome_pie_action_registry__types = NULL;
static GeeHashMap* gnome_pie_action_registry__descriptions;
static GeeHashMap* gnome_pie_action_registry__descriptions = NULL;
static gint GnomePieActionRegistryTypeDescription_private_offset;
static gpointer gnome_pie_action_registry_typedescription_parent_class = NULL;

VALA_EXTERN GType gnome_pie_action_registry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieActionRegistry, g_object_unref)
VALA_EXTERN gpointer gnome_pie_action_registry_typedescription_ref (gpointer instance);
VALA_EXTERN void gnome_pie_action_registry_typedescription_unref (gpointer instance);
VALA_EXTERN GParamSpec* gnome_pie_action_registry_param_spec_typedescription (const gchar* name,
                                                                  const gchar* nick,
                                                                  const gchar* blurb,
                                                                  GType object_type,
                                                                  GParamFlags flags);
VALA_EXTERN void gnome_pie_action_registry_value_set_typedescription (GValue* value,
                                                          gpointer v_object);
VALA_EXTERN void gnome_pie_action_registry_value_take_typedescription (GValue* value,
                                                           gpointer v_object);
VALA_EXTERN gpointer gnome_pie_action_registry_value_get_typedescription (const GValue* value);
VALA_EXTERN GType gnome_pie_action_registry_typedescription_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieActionRegistryTypeDescription, gnome_pie_action_registry_typedescription_unref)
VALA_EXTERN void gnome_pie_action_registry_init (void);
static void gnome_pie_action_registry_set_types (GeeArrayList* value);
static void gnome_pie_action_registry_set_descriptions (GeeHashMap* value);
VALA_EXTERN GeeArrayList* gnome_pie_action_registry_get_types (void);
VALA_EXTERN GType gnome_pie_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieAction, g_object_unref)
VALA_EXTERN GType gnome_pie_app_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieAppAction, g_object_unref)
VALA_EXTERN GnomePieActionRegistryTypeDescription* gnome_pie_app_action_register (void);
VALA_EXTERN GeeHashMap* gnome_pie_action_registry_get_descriptions (void);
VALA_EXTERN GType gnome_pie_key_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieKeyAction, g_object_unref)
VALA_EXTERN GnomePieActionRegistryTypeDescription* gnome_pie_key_action_register (void);
VALA_EXTERN GType gnome_pie_pie_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePiePieAction, g_object_unref)
VALA_EXTERN GnomePieActionRegistryTypeDescription* gnome_pie_pie_action_register (void);
VALA_EXTERN GType gnome_pie_uri_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieUriAction, g_object_unref)
VALA_EXTERN GnomePieActionRegistryTypeDescription* gnome_pie_uri_action_register (void);
VALA_EXTERN GnomePieAction* gnome_pie_action_registry_create_action (const gchar* type_id,
                                                         const gchar* name,
                                                         const gchar* icon,
                                                         const gchar* command,
                                                         gboolean quickaction);
VALA_EXTERN GnomePieAppAction* gnome_pie_app_action_new (const gchar* name,
                                             const gchar* icon,
                                             const gchar* command,
                                             gboolean is_quickaction);
VALA_EXTERN GnomePieAppAction* gnome_pie_app_action_construct (GType object_type,
                                                   const gchar* name,
                                                   const gchar* icon,
                                                   const gchar* command,
                                                   gboolean is_quickaction);
VALA_EXTERN GnomePieKeyAction* gnome_pie_key_action_new (const gchar* name,
                                             const gchar* icon,
                                             const gchar* command,
                                             gboolean is_quickaction);
VALA_EXTERN GnomePieKeyAction* gnome_pie_key_action_construct (GType object_type,
                                                   const gchar* name,
                                                   const gchar* icon,
                                                   const gchar* command,
                                                   gboolean is_quickaction);
VALA_EXTERN GnomePieUriAction* gnome_pie_uri_action_new (const gchar* name,
                                             const gchar* icon,
                                             const gchar* command,
                                             gboolean is_quickaction);
VALA_EXTERN GnomePieUriAction* gnome_pie_uri_action_construct (GType object_type,
                                                   const gchar* name,
                                                   const gchar* icon,
                                                   const gchar* command,
                                                   gboolean is_quickaction);
VALA_EXTERN GnomePiePieAction* gnome_pie_pie_action_new (const gchar* id,
                                             gboolean is_quickaction);
VALA_EXTERN GnomePiePieAction* gnome_pie_pie_action_construct (GType object_type,
                                                   const gchar* id,
                                                   gboolean is_quickaction);
VALA_EXTERN GnomePieAction* gnome_pie_action_registry_new_for_uri (const gchar* uri,
                                                       const gchar* name);
VALA_EXTERN GnomePieAction* gnome_pie_action_registry_new_for_desktop_file (const gchar* file_name);
static gchar* gnome_pie_action_registry_get_domain_name (const gchar* url);
VALA_EXTERN GnomePieAction* gnome_pie_action_registry_new_for_app_info (GAppInfo* info);
VALA_EXTERN const gchar* gnome_pie_paths_get_launchers (void);
VALA_EXTERN GnomePieAction* gnome_pie_action_registry_default_for_mime_type (const gchar* type);
VALA_EXTERN GnomePieAction* gnome_pie_action_registry_default_for_uri (const gchar* uri);
VALA_EXTERN GnomePieActionRegistry* gnome_pie_action_registry_new (void);
VALA_EXTERN GnomePieActionRegistry* gnome_pie_action_registry_construct (GType object_type);
VALA_EXTERN GnomePieActionRegistryTypeDescription* gnome_pie_action_registry_typedescription_new (void);
VALA_EXTERN GnomePieActionRegistryTypeDescription* gnome_pie_action_registry_typedescription_construct (GType object_type);
VALA_EXTERN const gchar* gnome_pie_action_registry_typedescription_get_name (GnomePieActionRegistryTypeDescription* self);
VALA_EXTERN void gnome_pie_action_registry_typedescription_set_name (GnomePieActionRegistryTypeDescription* self,
                                                         const gchar* value);
VALA_EXTERN const gchar* gnome_pie_action_registry_typedescription_get_icon (GnomePieActionRegistryTypeDescription* self);
VALA_EXTERN void gnome_pie_action_registry_typedescription_set_icon (GnomePieActionRegistryTypeDescription* self,
                                                         const gchar* value);
VALA_EXTERN const gchar* gnome_pie_action_registry_typedescription_get_description (GnomePieActionRegistryTypeDescription* self);
VALA_EXTERN void gnome_pie_action_registry_typedescription_set_description (GnomePieActionRegistryTypeDescription* self,
                                                                const gchar* value);
VALA_EXTERN const gchar* gnome_pie_action_registry_typedescription_get_id (GnomePieActionRegistryTypeDescription* self);
VALA_EXTERN void gnome_pie_action_registry_typedescription_set_id (GnomePieActionRegistryTypeDescription* self,
                                                       const gchar* value);
VALA_EXTERN gboolean gnome_pie_action_registry_typedescription_get_icon_name_editable (GnomePieActionRegistryTypeDescription* self);
VALA_EXTERN void gnome_pie_action_registry_typedescription_set_icon_name_editable (GnomePieActionRegistryTypeDescription* self,
                                                                       gboolean value);
static void gnome_pie_action_registry_typedescription_finalize (GnomePieActionRegistryTypeDescription * obj);
static GType gnome_pie_action_registry_typedescription_get_type_once (void);
static void gnome_pie_action_registry_finalize (GObject * obj);
static GType gnome_pie_action_registry_get_type_once (void);
static void _vala_gnome_pie_action_registry_get_property (GObject * object,
                                                   guint property_id,
                                                   GValue * value,
                                                   GParamSpec * pspec);
static void _vala_gnome_pie_action_registry_set_property (GObject * object,
                                                   guint property_id,
                                                   const GValue * value,
                                                   GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);
static gssize _vala_array_length (gpointer array);

void
gnome_pie_action_registry_init (void)
{
	GeeArrayList* _tmp0_;
	GeeArrayList* _tmp1_;
	GeeHashMap* _tmp2_;
	GeeHashMap* _tmp3_;
	GnomePieActionRegistryTypeDescription* type_description = NULL;
	GeeArrayList* _tmp4_;
	GeeArrayList* _tmp5_;
	const gchar* _tmp6_;
	GnomePieActionRegistryTypeDescription* _tmp7_;
	GeeHashMap* _tmp8_;
	GeeHashMap* _tmp9_;
	const gchar* _tmp10_;
	GnomePieActionRegistryTypeDescription* _tmp11_;
	GeeArrayList* _tmp12_;
	GeeArrayList* _tmp13_;
	const gchar* _tmp14_;
	GnomePieActionRegistryTypeDescription* _tmp15_;
	GeeHashMap* _tmp16_;
	GeeHashMap* _tmp17_;
	const gchar* _tmp18_;
	GnomePieActionRegistryTypeDescription* _tmp19_;
	GeeArrayList* _tmp20_;
	GeeArrayList* _tmp21_;
	const gchar* _tmp22_;
	GnomePieActionRegistryTypeDescription* _tmp23_;
	GeeHashMap* _tmp24_;
	GeeHashMap* _tmp25_;
	const gchar* _tmp26_;
	GnomePieActionRegistryTypeDescription* _tmp27_;
	GeeArrayList* _tmp28_;
	GeeArrayList* _tmp29_;
	const gchar* _tmp30_;
	GnomePieActionRegistryTypeDescription* _tmp31_;
	GeeHashMap* _tmp32_;
	GeeHashMap* _tmp33_;
	const gchar* _tmp34_;
	GnomePieActionRegistryTypeDescription* _tmp35_;
	_tmp0_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL);
	_tmp1_ = _tmp0_;
	gnome_pie_action_registry_set_types (_tmp1_);
	_g_object_unref0 (_tmp1_);
	_tmp2_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION, (GBoxedCopyFunc) gnome_pie_action_registry_typedescription_ref, (GDestroyNotify) gnome_pie_action_registry_typedescription_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	_tmp3_ = _tmp2_;
	gnome_pie_action_registry_set_descriptions (_tmp3_);
	_g_object_unref0 (_tmp3_);
	_tmp4_ = gnome_pie_action_registry_get_types ();
	_tmp5_ = _tmp4_;
	_tmp6_ = g_type_name (GNOME_PIE_TYPE_APP_ACTION);
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp5_, _tmp6_);
	_tmp7_ = gnome_pie_app_action_register ();
	_gnome_pie_action_registry_typedescription_unref0 (type_description);
	type_description = _tmp7_;
	_tmp8_ = gnome_pie_action_registry_get_descriptions ();
	_tmp9_ = _tmp8_;
	_tmp10_ = g_type_name (GNOME_PIE_TYPE_APP_ACTION);
	_tmp11_ = type_description;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp9_, _tmp10_, _tmp11_);
	_tmp12_ = gnome_pie_action_registry_get_types ();
	_tmp13_ = _tmp12_;
	_tmp14_ = g_type_name (GNOME_PIE_TYPE_KEY_ACTION);
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp13_, _tmp14_);
	_tmp15_ = gnome_pie_key_action_register ();
	_gnome_pie_action_registry_typedescription_unref0 (type_description);
	type_description = _tmp15_;
	_tmp16_ = gnome_pie_action_registry_get_descriptions ();
	_tmp17_ = _tmp16_;
	_tmp18_ = g_type_name (GNOME_PIE_TYPE_KEY_ACTION);
	_tmp19_ = type_description;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp17_, _tmp18_, _tmp19_);
	_tmp20_ = gnome_pie_action_registry_get_types ();
	_tmp21_ = _tmp20_;
	_tmp22_ = g_type_name (GNOME_PIE_TYPE_PIE_ACTION);
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp21_, _tmp22_);
	_tmp23_ = gnome_pie_pie_action_register ();
	_gnome_pie_action_registry_typedescription_unref0 (type_description);
	type_description = _tmp23_;
	_tmp24_ = gnome_pie_action_registry_get_descriptions ();
	_tmp25_ = _tmp24_;
	_tmp26_ = g_type_name (GNOME_PIE_TYPE_PIE_ACTION);
	_tmp27_ = type_description;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp25_, _tmp26_, _tmp27_);
	_tmp28_ = gnome_pie_action_registry_get_types ();
	_tmp29_ = _tmp28_;
	_tmp30_ = g_type_name (GNOME_PIE_TYPE_URI_ACTION);
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp29_, _tmp30_);
	_tmp31_ = gnome_pie_uri_action_register ();
	_gnome_pie_action_registry_typedescription_unref0 (type_description);
	type_description = _tmp31_;
	_tmp32_ = gnome_pie_action_registry_get_descriptions ();
	_tmp33_ = _tmp32_;
	_tmp34_ = g_type_name (GNOME_PIE_TYPE_URI_ACTION);
	_tmp35_ = type_description;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp33_, _tmp34_, _tmp35_);
	_gnome_pie_action_registry_typedescription_unref0 (type_description);
}

GnomePieAction*
gnome_pie_action_registry_create_action (const gchar* type_id,
                                         const gchar* name,
                                         const gchar* icon,
                                         const gchar* command,
                                         gboolean quickaction)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	static GQuark _tmp1_label2 = 0;
	static GQuark _tmp1_label3 = 0;
	GnomePieAction* result;
	g_return_val_if_fail (type_id != NULL, NULL);
	g_return_val_if_fail (name != NULL, NULL);
	g_return_val_if_fail (icon != NULL, NULL);
	g_return_val_if_fail (command != NULL, NULL);
	_tmp0_ = type_id;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("app")))) {
		switch (0) {
			default:
			{
				GnomePieAppAction* _tmp3_;
				_tmp3_ = gnome_pie_app_action_new (name, icon, command, quickaction);
				result = (GnomePieAction*) _tmp3_;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("key")))) {
		switch (0) {
			default:
			{
				GnomePieKeyAction* _tmp4_;
				_tmp4_ = gnome_pie_key_action_new (name, icon, command, quickaction);
				result = (GnomePieAction*) _tmp4_;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label2) ? _tmp1_label2 : (_tmp1_label2 = g_quark_from_static_string ("uri")))) {
		switch (0) {
			default:
			{
				GnomePieUriAction* _tmp5_;
				_tmp5_ = gnome_pie_uri_action_new (name, icon, command, quickaction);
				result = (GnomePieAction*) _tmp5_;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label3) ? _tmp1_label3 : (_tmp1_label3 = g_quark_from_static_string ("pie")))) {
		switch (0) {
			default:
			{
				GnomePiePieAction* _tmp6_;
				_tmp6_ = gnome_pie_pie_action_new (command, quickaction);
				result = (GnomePieAction*) _tmp6_;
				return result;
			}
		}
	}
	result = NULL;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

GnomePieAction*
gnome_pie_action_registry_new_for_uri (const gchar* uri,
                                       const gchar* name)
{
	GFile* file = NULL;
	GFile* _tmp0_;
	gchar* scheme = NULL;
	GFile* _tmp1_;
	gchar* _tmp2_;
	gchar* final_icon = NULL;
	gchar* _tmp3_;
	gchar* final_name = NULL;
	GFile* _tmp4_;
	gchar* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	GQuark _tmp9_ = 0U;
	static GQuark _tmp8_label0 = 0;
	static GQuark _tmp8_label1 = 0;
	static GQuark _tmp8_label2 = 0;
	static GQuark _tmp8_label3 = 0;
	static GQuark _tmp8_label4 = 0;
	static GQuark _tmp8_label5 = 0;
	const gchar* _tmp50_;
	const gchar* _tmp51_;
	GnomePieUriAction* _tmp52_;
	GError* _inner_error0_ = NULL;
	GnomePieAction* result;
	g_return_val_if_fail (uri != NULL, NULL);
	_tmp0_ = g_file_new_for_uri (uri);
	file = _tmp0_;
	_tmp1_ = file;
	_tmp2_ = g_file_get_uri_scheme (_tmp1_);
	scheme = _tmp2_;
	_tmp3_ = g_strdup ("");
	final_icon = _tmp3_;
	_tmp4_ = file;
	_tmp5_ = g_file_get_basename (_tmp4_);
	final_name = _tmp5_;
	_tmp6_ = scheme;
	_tmp7_ = _tmp6_;
	_tmp9_ = (NULL == _tmp7_) ? 0 : g_quark_from_string (_tmp7_);
	if (_tmp9_ == ((0 != _tmp8_label0) ? _tmp8_label0 : (_tmp8_label0 = g_quark_from_static_string ("application")))) {
		switch (0) {
			default:
			{
				gchar* file_name = NULL;
				gchar** _tmp10_;
				gchar** _tmp11_;
				gchar** _tmp12_;
				gint _tmp12__length1;
				const gchar* _tmp13_;
				gchar* _tmp14_;
				gchar* _tmp15_;
				GFile* desktop_file = NULL;
				const gchar* _tmp16_;
				gchar* _tmp17_;
				gchar* _tmp18_;
				GFile* _tmp19_;
				GFile* _tmp20_;
				GFile* _tmp21_;
				_tmp11_ = _tmp10_ = g_strsplit (uri, "//", 0);
				_tmp12_ = _tmp11_;
				_tmp12__length1 = _vala_array_length (_tmp10_);
				_tmp13_ = _tmp12_[1];
				_tmp14_ = g_strdup (_tmp13_);
				_tmp15_ = _tmp14_;
				_tmp12_ = (_vala_array_free (_tmp12_, _tmp12__length1, (GDestroyNotify) g_free), NULL);
				file_name = _tmp15_;
				_tmp16_ = file_name;
				_tmp17_ = g_strconcat ("/usr/share/applications/", _tmp16_, NULL);
				_tmp18_ = _tmp17_;
				_tmp19_ = g_file_new_for_path (_tmp18_);
				_tmp20_ = _tmp19_;
				_g_free0 (_tmp18_);
				desktop_file = _tmp20_;
				_tmp21_ = desktop_file;
				if (g_file_query_exists (_tmp21_, NULL)) {
					GFile* _tmp22_;
					gchar* _tmp23_;
					gchar* _tmp24_;
					GnomePieAction* _tmp25_;
					GnomePieAction* _tmp26_;
					_tmp22_ = desktop_file;
					_tmp23_ = g_file_get_path (_tmp22_);
					_tmp24_ = _tmp23_;
					_tmp25_ = gnome_pie_action_registry_new_for_desktop_file (_tmp24_);
					_tmp26_ = _tmp25_;
					_g_free0 (_tmp24_);
					result = _tmp26_;
					_g_object_unref0 (desktop_file);
					_g_free0 (file_name);
					_g_free0 (final_name);
					_g_free0 (final_icon);
					_g_free0 (scheme);
					_g_object_unref0 (file);
					return result;
				}
				_g_object_unref0 (desktop_file);
				_g_free0 (file_name);
				break;
			}
		}
	} else if (_tmp9_ == ((0 != _tmp8_label1) ? _tmp8_label1 : (_tmp8_label1 = g_quark_from_static_string ("trash")))) {
		switch (0) {
			default:
			{
				gchar* _tmp27_;
				gchar* _tmp28_;
				_tmp27_ = g_strdup ("user-trash");
				_g_free0 (final_icon);
				final_icon = _tmp27_;
				_tmp28_ = g_strdup (_ ("Trash"));
				_g_free0 (final_name);
				final_name = _tmp28_;
				break;
			}
		}
	} else if ((_tmp9_ == ((0 != _tmp8_label2) ? _tmp8_label2 : (_tmp8_label2 = g_quark_from_static_string ("http")))) || (_tmp9_ == ((0 != _tmp8_label3) ? _tmp8_label3 : (_tmp8_label3 = g_quark_from_static_string ("https"))))) {
		switch (0) {
			default:
			{
				gchar* _tmp29_;
				gchar* _tmp30_;
				_tmp29_ = g_strdup ("www");
				_g_free0 (final_icon);
				final_icon = _tmp29_;
				_tmp30_ = gnome_pie_action_registry_get_domain_name (uri);
				_g_free0 (final_name);
				final_name = _tmp30_;
				break;
			}
		}
	} else if ((_tmp9_ == ((0 != _tmp8_label4) ? _tmp8_label4 : (_tmp8_label4 = g_quark_from_static_string ("ftp")))) || (_tmp9_ == ((0 != _tmp8_label5) ? _tmp8_label5 : (_tmp8_label5 = g_quark_from_static_string ("sftp"))))) {
		switch (0) {
			default:
			{
				gchar* _tmp31_;
				gchar* _tmp32_;
				_tmp31_ = g_strdup ("folder-remote");
				_g_free0 (final_icon);
				final_icon = _tmp31_;
				_tmp32_ = gnome_pie_action_registry_get_domain_name (uri);
				_g_free0 (final_name);
				final_name = _tmp32_;
				break;
			}
		}
	} else {
		switch (0) {
			default:
			{
				{
					GFileInfo* info = NULL;
					GFile* _tmp33_;
					GFileInfo* _tmp34_;
					GFileInfo* _tmp35_;
					const gchar* _tmp36_;
					GIcon* icon = NULL;
					GFileInfo* _tmp42_;
					GIcon* _tmp43_;
					GIcon* _tmp44_;
					GIcon* _tmp45_;
					gchar* _tmp46_;
					_tmp33_ = file;
					_tmp34_ = g_file_query_info (_tmp33_, "*", G_FILE_QUERY_INFO_NONE, NULL, &_inner_error0_);
					info = _tmp34_;
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
						goto __catch0_g_error;
					}
					_tmp35_ = info;
					_tmp36_ = g_file_info_get_content_type (_tmp35_);
					if (g_strcmp0 (_tmp36_, "application/x-desktop") == 0) {
						GFile* _tmp37_;
						gchar* _tmp38_;
						gchar* _tmp39_;
						GnomePieAction* _tmp40_;
						GnomePieAction* _tmp41_;
						_tmp37_ = file;
						_tmp38_ = g_file_get_parse_name (_tmp37_);
						_tmp39_ = _tmp38_;
						_tmp40_ = gnome_pie_action_registry_new_for_desktop_file (_tmp39_);
						_tmp41_ = _tmp40_;
						_g_free0 (_tmp39_);
						result = _tmp41_;
						_g_object_unref0 (info);
						_g_free0 (final_name);
						_g_free0 (final_icon);
						_g_free0 (scheme);
						_g_object_unref0 (file);
						return result;
					}
					_tmp42_ = info;
					_tmp43_ = g_file_info_get_icon (_tmp42_);
					_tmp44_ = _g_object_ref0 (_tmp43_);
					icon = _tmp44_;
					_tmp45_ = icon;
					_tmp46_ = g_icon_to_string (_tmp45_);
					_g_free0 (final_icon);
					final_icon = _tmp46_;
					_g_object_unref0 (icon);
					_g_object_unref0 (info);
				}
				goto __finally0;
				__catch0_g_error:
				{
					GError* e = NULL;
					GError* _tmp47_;
					const gchar* _tmp48_;
					e = _inner_error0_;
					_inner_error0_ = NULL;
					_tmp47_ = e;
					_tmp48_ = _tmp47_->message;
					g_warning ("actionRegistry.vala:150: %s", _tmp48_);
					_g_error_free0 (e);
				}
				__finally0:
				if (G_UNLIKELY (_inner_error0_ != NULL)) {
					_g_free0 (final_name);
					_g_free0 (final_icon);
					_g_free0 (scheme);
					_g_object_unref0 (file);
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
					g_clear_error (&_inner_error0_);
					return NULL;
				}
				break;
			}
		}
	}
	if (name != NULL) {
		gchar* _tmp49_;
		_tmp49_ = g_strdup (name);
		_g_free0 (final_name);
		final_name = _tmp49_;
	}
	_tmp50_ = final_name;
	_tmp51_ = final_icon;
	_tmp52_ = gnome_pie_uri_action_new (_tmp50_, _tmp51_, uri, FALSE);
	result = (GnomePieAction*) _tmp52_;
	_g_free0 (final_name);
	_g_free0 (final_icon);
	_g_free0 (scheme);
	_g_object_unref0 (file);
	return result;
}

GnomePieAction*
gnome_pie_action_registry_new_for_app_info (GAppInfo* info)
{
	GIcon* icon = NULL;
	GIcon* _tmp0_;
	GIcon* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	GnomePieAppAction* _tmp6_;
	GnomePieAction* _tmp7_;
	GnomePieAction* result;
	g_return_val_if_fail (info != NULL, NULL);
	_tmp0_ = g_app_info_get_icon (info);
	_tmp1_ = _g_object_ref0 (_tmp0_);
	icon = _tmp1_;
	_tmp2_ = g_app_info_get_display_name (info);
	_tmp3_ = g_icon_to_string (icon);
	_tmp4_ = _tmp3_;
	_tmp5_ = g_app_info_get_commandline (info);
	_tmp6_ = gnome_pie_app_action_new (_tmp2_, _tmp4_, _tmp5_, FALSE);
	_tmp7_ = (GnomePieAction*) _tmp6_;
	_g_free0 (_tmp4_);
	result = _tmp7_;
	_g_object_unref0 (icon);
	return result;
}

static glong
string_strnlen (gchar* str,
                glong maxlen)
{
	gchar* end = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	glong result;
	_tmp0_ = memchr (str, 0, (gsize) maxlen);
	end = _tmp0_;
	_tmp1_ = end;
	if (_tmp1_ == NULL) {
		result = maxlen;
		return result;
	} else {
		gchar* _tmp2_;
		_tmp2_ = end;
		result = (glong) (_tmp2_ - str);
		return result;
	}
}

static gchar*
string_substring (const gchar* self,
                  glong offset,
                  glong len)
{
	glong string_length = 0L;
	gboolean _tmp0_ = FALSE;
	gchar* _tmp3_;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	if (offset >= ((glong) 0)) {
		_tmp0_ = len >= ((glong) 0);
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		string_length = string_strnlen ((gchar*) self, offset + len);
	} else {
		gint _tmp1_;
		gint _tmp2_;
		_tmp1_ = strlen (self);
		_tmp2_ = _tmp1_;
		string_length = (glong) _tmp2_;
	}
	if (offset < ((glong) 0)) {
		offset = string_length + offset;
		g_return_val_if_fail (offset >= ((glong) 0), NULL);
	} else {
		g_return_val_if_fail (offset <= string_length, NULL);
	}
	if (len < ((glong) 0)) {
		len = string_length - offset;
	}
	g_return_val_if_fail ((offset + len) <= string_length, NULL);
	_tmp3_ = g_strndup (((gchar*) self) + offset, (gsize) len);
	result = _tmp3_;
	return result;
}

GnomePieAction*
gnome_pie_action_registry_new_for_desktop_file (const gchar* file_name)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GDesktopAppInfo* info = NULL;
	GDesktopAppInfo* _tmp7_;
	GDesktopAppInfo* _tmp8_;
	GnomePieAction* _tmp9_;
	GnomePieAction* result;
	g_return_val_if_fail (file_name != NULL, NULL);
	_tmp0_ = gnome_pie_paths_get_launchers ();
	_tmp1_ = _tmp0_;
	if (g_str_has_prefix (file_name, _tmp1_)) {
		gchar* id = NULL;
		gint _tmp2_;
		gint _tmp3_;
		gchar* _tmp4_;
		const gchar* _tmp5_;
		GnomePiePieAction* _tmp6_;
		_tmp2_ = strlen (file_name);
		_tmp3_ = _tmp2_;
		_tmp4_ = string_substring (file_name, ((glong) _tmp3_) - 11, (glong) 3);
		id = _tmp4_;
		_tmp5_ = id;
		_tmp6_ = gnome_pie_pie_action_new (_tmp5_, FALSE);
		result = (GnomePieAction*) _tmp6_;
		_g_free0 (id);
		return result;
	}
	_tmp7_ = g_desktop_app_info_new_from_filename (file_name);
	info = _tmp7_;
	_tmp8_ = info;
	_tmp9_ = gnome_pie_action_registry_new_for_app_info ((GAppInfo*) _tmp8_);
	result = _tmp9_;
	_g_object_unref0 (info);
	return result;
}

GnomePieAction*
gnome_pie_action_registry_default_for_mime_type (const gchar* type)
{
	GAppInfo* info = NULL;
	GAppInfo* _tmp0_;
	GnomePieAction* _tmp1_;
	GnomePieAction* result;
	g_return_val_if_fail (type != NULL, NULL);
	_tmp0_ = g_app_info_get_default_for_type (type, FALSE);
	info = _tmp0_;
	_tmp1_ = gnome_pie_action_registry_new_for_app_info (info);
	result = _tmp1_;
	_g_object_unref0 (info);
	return result;
}

GnomePieAction*
gnome_pie_action_registry_default_for_uri (const gchar* uri)
{
	GAppInfo* info = NULL;
	GAppInfo* _tmp0_;
	GnomePieAction* _tmp1_;
	GnomePieAction* result;
	g_return_val_if_fail (uri != NULL, NULL);
	_tmp0_ = g_app_info_get_default_for_uri_scheme (uri);
	info = _tmp0_;
	_tmp1_ = gnome_pie_action_registry_new_for_app_info (info);
	result = _tmp1_;
	_g_object_unref0 (info);
	return result;
}

static gint
string_index_of_char (const gchar* self,
                      gunichar c,
                      gint start_index)
{
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gint result;
	g_return_val_if_fail (self != NULL, 0);
	_tmp0_ = g_utf8_strchr (((gchar*) self) + start_index, (gssize) -1, c);
	_result_ = _tmp0_;
	_tmp1_ = _result_;
	if (_tmp1_ != NULL) {
		gchar* _tmp2_;
		_tmp2_ = _result_;
		result = (gint) (_tmp2_ - ((gchar*) self));
		return result;
	} else {
		result = -1;
		return result;
	}
}

static gchar*
gnome_pie_action_registry_get_domain_name (const gchar* url)
{
	gint domain_end = 0;
	gint domain_begin = 0;
	gchar* _tmp1_;
	gchar* result;
	g_return_val_if_fail (url != NULL, NULL);
	domain_end = string_index_of_char (url, (gunichar) '/', 7);
	domain_begin = string_index_of_char (url, (gunichar) '/', 0) + 2;
	if (domain_begin < domain_end) {
		gchar* _tmp0_;
		_tmp0_ = string_substring (url, (glong) domain_begin, (glong) (domain_end - domain_begin));
		result = _tmp0_;
		return result;
	}
	_tmp1_ = g_strdup (url);
	result = _tmp1_;
	return result;
}

GnomePieActionRegistry*
gnome_pie_action_registry_construct (GType object_type)
{
	GnomePieActionRegistry * self = NULL;
	self = (GnomePieActionRegistry*) g_object_new (object_type, NULL);
	return self;
}

GnomePieActionRegistry*
gnome_pie_action_registry_new (void)
{
	return gnome_pie_action_registry_construct (GNOME_PIE_TYPE_ACTION_REGISTRY);
}

GeeArrayList*
gnome_pie_action_registry_get_types (void)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	_tmp0_ = gnome_pie_action_registry__types;
	result = _tmp0_;
	return result;
}

static void
gnome_pie_action_registry_set_types (GeeArrayList* value)
{
	GeeArrayList* _tmp0_;
	_tmp0_ = _g_object_ref0 (value);
	_g_object_unref0 (gnome_pie_action_registry__types);
	gnome_pie_action_registry__types = _tmp0_;
}

GeeHashMap*
gnome_pie_action_registry_get_descriptions (void)
{
	GeeHashMap* result;
	GeeHashMap* _tmp0_;
	_tmp0_ = gnome_pie_action_registry__descriptions;
	result = _tmp0_;
	return result;
}

static void
gnome_pie_action_registry_set_descriptions (GeeHashMap* value)
{
	GeeHashMap* _tmp0_;
	_tmp0_ = _g_object_ref0 (value);
	_g_object_unref0 (gnome_pie_action_registry__descriptions);
	gnome_pie_action_registry__descriptions = _tmp0_;
}

static inline gpointer
gnome_pie_action_registry_typedescription_get_instance_private (GnomePieActionRegistryTypeDescription* self)
{
	return G_STRUCT_MEMBER_P (self, GnomePieActionRegistryTypeDescription_private_offset);
}

GnomePieActionRegistryTypeDescription*
gnome_pie_action_registry_typedescription_construct (GType object_type)
{
	GnomePieActionRegistryTypeDescription* self = NULL;
	self = (GnomePieActionRegistryTypeDescription*) g_type_create_instance (object_type);
	return self;
}

GnomePieActionRegistryTypeDescription*
gnome_pie_action_registry_typedescription_new (void)
{
	return gnome_pie_action_registry_typedescription_construct (GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION);
}

const gchar*
gnome_pie_action_registry_typedescription_get_name (GnomePieActionRegistryTypeDescription* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_name;
	result = _tmp0_;
	return result;
}

void
gnome_pie_action_registry_typedescription_set_name (GnomePieActionRegistryTypeDescription* self,
                                                    const gchar* value)
{
	gchar* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_name);
	self->priv->_name = _tmp0_;
}

const gchar*
gnome_pie_action_registry_typedescription_get_icon (GnomePieActionRegistryTypeDescription* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_icon;
	result = _tmp0_;
	return result;
}

void
gnome_pie_action_registry_typedescription_set_icon (GnomePieActionRegistryTypeDescription* self,
                                                    const gchar* value)
{
	gchar* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_icon);
	self->priv->_icon = _tmp0_;
}

const gchar*
gnome_pie_action_registry_typedescription_get_description (GnomePieActionRegistryTypeDescription* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_description;
	result = _tmp0_;
	return result;
}

void
gnome_pie_action_registry_typedescription_set_description (GnomePieActionRegistryTypeDescription* self,
                                                           const gchar* value)
{
	gchar* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_description);
	self->priv->_description = _tmp0_;
}

const gchar*
gnome_pie_action_registry_typedescription_get_id (GnomePieActionRegistryTypeDescription* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
gnome_pie_action_registry_typedescription_set_id (GnomePieActionRegistryTypeDescription* self,
                                                  const gchar* value)
{
	gchar* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = g_strdup (value);
	_g_free0 (self->priv->_id);
	self->priv->_id = _tmp0_;
}

gboolean
gnome_pie_action_registry_typedescription_get_icon_name_editable (GnomePieActionRegistryTypeDescription* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_icon_name_editable;
	return result;
}

void
gnome_pie_action_registry_typedescription_set_icon_name_editable (GnomePieActionRegistryTypeDescription* self,
                                                                  gboolean value)
{
	g_return_if_fail (self != NULL);
	self->priv->_icon_name_editable = value;
}

static void
gnome_pie_action_registry_value_typedescription_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
gnome_pie_action_registry_value_typedescription_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		gnome_pie_action_registry_typedescription_unref (value->data[0].v_pointer);
	}
}

static void
gnome_pie_action_registry_value_typedescription_copy_value (const GValue* src_value,
                                                            GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = gnome_pie_action_registry_typedescription_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
gnome_pie_action_registry_value_typedescription_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
gnome_pie_action_registry_value_typedescription_collect_value (GValue* value,
                                                               guint n_collect_values,
                                                               GTypeCValue* collect_values,
                                                               guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		GnomePieActionRegistryTypeDescription * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = gnome_pie_action_registry_typedescription_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
gnome_pie_action_registry_value_typedescription_lcopy_value (const GValue* value,
                                                             guint n_collect_values,
                                                             GTypeCValue* collect_values,
                                                             guint collect_flags)
{
	GnomePieActionRegistryTypeDescription ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = gnome_pie_action_registry_typedescription_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
gnome_pie_action_registry_param_spec_typedescription (const gchar* name,
                                                      const gchar* nick,
                                                      const gchar* blurb,
                                                      GType object_type,
                                                      GParamFlags flags)
{
	GnomePieActionRegistryParamSpecTypeDescription* spec;
	g_return_val_if_fail (g_type_is_a (object_type, GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
gnome_pie_action_registry_value_get_typedescription (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION), NULL);
	return value->data[0].v_pointer;
}

void
gnome_pie_action_registry_value_set_typedescription (GValue* value,
                                                     gpointer v_object)
{
	GnomePieActionRegistryTypeDescription * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		gnome_pie_action_registry_typedescription_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		gnome_pie_action_registry_typedescription_unref (old);
	}
}

void
gnome_pie_action_registry_value_take_typedescription (GValue* value,
                                                      gpointer v_object)
{
	GnomePieActionRegistryTypeDescription * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		gnome_pie_action_registry_typedescription_unref (old);
	}
}

static void
gnome_pie_action_registry_typedescription_class_init (GnomePieActionRegistryTypeDescriptionClass * klass,
                                                      gpointer klass_data)
{
	gnome_pie_action_registry_typedescription_parent_class = g_type_class_peek_parent (klass);
	((GnomePieActionRegistryTypeDescriptionClass *) klass)->finalize = gnome_pie_action_registry_typedescription_finalize;
	g_type_class_adjust_private_offset (klass, &GnomePieActionRegistryTypeDescription_private_offset);
}

static void
gnome_pie_action_registry_typedescription_instance_init (GnomePieActionRegistryTypeDescription * self,
                                                         gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	self->priv = gnome_pie_action_registry_typedescription_get_instance_private (self);
	_tmp0_ = g_strdup ("");
	self->priv->_name = _tmp0_;
	_tmp1_ = g_strdup ("");
	self->priv->_icon = _tmp1_;
	_tmp2_ = g_strdup ("");
	self->priv->_description = _tmp2_;
	_tmp3_ = g_strdup ("");
	self->priv->_id = _tmp3_;
	self->priv->_icon_name_editable = FALSE;
	self->ref_count = 1;
}

static void
gnome_pie_action_registry_typedescription_finalize (GnomePieActionRegistryTypeDescription * obj)
{
	GnomePieActionRegistryTypeDescription * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieActionRegistryTypeDescription);
	g_signal_handlers_destroy (self);
	_g_free0 (self->priv->_name);
	_g_free0 (self->priv->_icon);
	_g_free0 (self->priv->_description);
	_g_free0 (self->priv->_id);
}

static GType
gnome_pie_action_registry_typedescription_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { gnome_pie_action_registry_value_typedescription_init, gnome_pie_action_registry_value_typedescription_free_value, gnome_pie_action_registry_value_typedescription_copy_value, gnome_pie_action_registry_value_typedescription_peek_pointer, "p", gnome_pie_action_registry_value_typedescription_collect_value, "p", gnome_pie_action_registry_value_typedescription_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (GnomePieActionRegistryTypeDescriptionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gnome_pie_action_registry_typedescription_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GnomePieActionRegistryTypeDescription), 0, (GInstanceInitFunc) gnome_pie_action_registry_typedescription_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType gnome_pie_action_registry_typedescription_type_id;
	gnome_pie_action_registry_typedescription_type_id = g_type_register_fundamental (g_type_fundamental_next (), "GnomePieActionRegistryTypeDescription", &g_define_type_info, &g_define_type_fundamental_info, 0);
	GnomePieActionRegistryTypeDescription_private_offset = g_type_add_instance_private (gnome_pie_action_registry_typedescription_type_id, sizeof (GnomePieActionRegistryTypeDescriptionPrivate));
	return gnome_pie_action_registry_typedescription_type_id;
}

GType
gnome_pie_action_registry_typedescription_get_type (void)
{
	static volatile gsize gnome_pie_action_registry_typedescription_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_action_registry_typedescription_type_id__once)) {
		GType gnome_pie_action_registry_typedescription_type_id;
		gnome_pie_action_registry_typedescription_type_id = gnome_pie_action_registry_typedescription_get_type_once ();
		g_once_init_leave (&gnome_pie_action_registry_typedescription_type_id__once, gnome_pie_action_registry_typedescription_type_id);
	}
	return gnome_pie_action_registry_typedescription_type_id__once;
}

gpointer
gnome_pie_action_registry_typedescription_ref (gpointer instance)
{
	GnomePieActionRegistryTypeDescription * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
gnome_pie_action_registry_typedescription_unref (gpointer instance)
{
	GnomePieActionRegistryTypeDescription * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		GNOME_PIE_ACTION_REGISTRY_TYPEDESCRIPTION_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

static void
gnome_pie_action_registry_class_init (GnomePieActionRegistryClass * klass,
                                      gpointer klass_data)
{
	gnome_pie_action_registry_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gnome_pie_action_registry_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gnome_pie_action_registry_set_property;
	G_OBJECT_CLASS (klass)->finalize = gnome_pie_action_registry_finalize;
}

static void
gnome_pie_action_registry_instance_init (GnomePieActionRegistry * self,
                                         gpointer klass)
{
}

static void
gnome_pie_action_registry_finalize (GObject * obj)
{
	GnomePieActionRegistry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_TYPE_ACTION_REGISTRY, GnomePieActionRegistry);
	G_OBJECT_CLASS (gnome_pie_action_registry_parent_class)->finalize (obj);
}

static GType
gnome_pie_action_registry_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GnomePieActionRegistryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gnome_pie_action_registry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GnomePieActionRegistry), 0, (GInstanceInitFunc) gnome_pie_action_registry_instance_init, NULL };
	GType gnome_pie_action_registry_type_id;
	gnome_pie_action_registry_type_id = g_type_register_static (G_TYPE_OBJECT, "GnomePieActionRegistry", &g_define_type_info, 0);
	return gnome_pie_action_registry_type_id;
}

GType
gnome_pie_action_registry_get_type (void)
{
	static volatile gsize gnome_pie_action_registry_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_action_registry_type_id__once)) {
		GType gnome_pie_action_registry_type_id;
		gnome_pie_action_registry_type_id = gnome_pie_action_registry_get_type_once ();
		g_once_init_leave (&gnome_pie_action_registry_type_id__once, gnome_pie_action_registry_type_id);
	}
	return gnome_pie_action_registry_type_id__once;
}

static void
_vala_gnome_pie_action_registry_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec)
{
	GnomePieActionRegistry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GNOME_PIE_TYPE_ACTION_REGISTRY, GnomePieActionRegistry);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gnome_pie_action_registry_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec)
{
	GnomePieActionRegistry * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GNOME_PIE_TYPE_ACTION_REGISTRY, GnomePieActionRegistry);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static gssize
_vala_array_length (gpointer array)
{
	gssize length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}

