/* pieAction.c generated by valac 0.56.18, the Vala compiler
 * generated from pieAction.vala, do not modify */

/*///////////////////////////////////////////////////////////////////////*/
/* Copyright 2011-2021 Simon Schneegans*/
/**/
/* Permission is hereby granted, free of charge, to any person obtaining*/
/* a copy of this software and associated documentation files (the*/
/* "Software"), to deal in the Software without restriction, including*/
/* without limitation the rights to use, copy, modify, merge, publish,*/
/* distribute, sublicense, and/or sell copies of the Software, and to*/
/* permit persons to whom the Software is furnished to do so, subject to*/
/* the following conditions:*/
/* */
/* The above copyright notice and this permission notice shall be*/
/* included in all copies or substantial portions of the Software.*/
/* */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,*/
/* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF*/
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.*/
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY*/
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,*/
/* TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE*/
/* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.*/
/*///////////////////////////////////////////////////////////////////////*/

#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gee.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GNOME_PIE_TYPE_ACTION (gnome_pie_action_get_type ())
#define GNOME_PIE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_ACTION, GnomePieAction))
#define GNOME_PIE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_ACTION, GnomePieActionClass))
#define GNOME_PIE_IS_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_ACTION))
#define GNOME_PIE_IS_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_ACTION))
#define GNOME_PIE_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_ACTION, GnomePieActionClass))

typedef struct _GnomePieAction GnomePieAction;
typedef struct _GnomePieActionClass GnomePieActionClass;
typedef struct _GnomePieActionPrivate GnomePieActionPrivate;

#define GNOME_PIE_TYPE_PIE_ACTION (gnome_pie_pie_action_get_type ())
#define GNOME_PIE_PIE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_PIE_ACTION, GnomePiePieAction))
#define GNOME_PIE_PIE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_PIE_ACTION, GnomePiePieActionClass))
#define GNOME_PIE_IS_PIE_ACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_PIE_ACTION))
#define GNOME_PIE_IS_PIE_ACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_PIE_ACTION))
#define GNOME_PIE_PIE_ACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_PIE_ACTION, GnomePiePieActionClass))

typedef struct _GnomePiePieAction GnomePiePieAction;
typedef struct _GnomePiePieActionClass GnomePiePieActionClass;
typedef struct _GnomePiePieActionPrivate GnomePiePieActionPrivate;
enum  {
	GNOME_PIE_PIE_ACTION_0_PROPERTY,
	GNOME_PIE_PIE_ACTION_REAL_COMMAND_PROPERTY,
	GNOME_PIE_PIE_ACTION_DISPLAY_COMMAND_PROPERTY,
	GNOME_PIE_PIE_ACTION_NAME_PROPERTY,
	GNOME_PIE_PIE_ACTION_ICON_PROPERTY,
	GNOME_PIE_PIE_ACTION_NUM_PROPERTIES
};
static GParamSpec* gnome_pie_pie_action_properties[GNOME_PIE_PIE_ACTION_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION (gnome_pie_action_registry_typedescription_get_type ())
#define GNOME_PIE_ACTION_REGISTRY_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieActionRegistryTypeDescription))
#define GNOME_PIE_ACTION_REGISTRY_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieActionRegistryTypeDescriptionClass))
#define GNOME_PIE_ACTION_REGISTRY_IS_TYPEDESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_ACTION_REGISTRY_IS_TYPEDESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION))
#define GNOME_PIE_ACTION_REGISTRY_TYPEDESCRIPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_ACTION_REGISTRY_TYPE_TYPEDESCRIPTION, GnomePieActionRegistryTypeDescriptionClass))

typedef struct _GnomePieActionRegistryTypeDescription GnomePieActionRegistryTypeDescription;
typedef struct _GnomePieActionRegistryTypeDescriptionClass GnomePieActionRegistryTypeDescriptionClass;

#define GNOME_PIE_TYPE_PIE (gnome_pie_pie_get_type ())
#define GNOME_PIE_PIE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_PIE_TYPE_PIE, GnomePiePie))
#define GNOME_PIE_PIE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_PIE_TYPE_PIE, GnomePiePieClass))
#define GNOME_PIE_IS_PIE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_PIE_TYPE_PIE))
#define GNOME_PIE_IS_PIE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_PIE_TYPE_PIE))
#define GNOME_PIE_PIE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_PIE_TYPE_PIE, GnomePiePieClass))

typedef struct _GnomePiePie GnomePiePie;
typedef struct _GnomePiePieClass GnomePiePieClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _GnomePieAction {
	GObject parent_instance;
	GnomePieActionPrivate * priv;
};

struct _GnomePieActionClass {
	GObjectClass parent_class;
	void (*activate) (GnomePieAction* self, guint32 time_stamp);
	const gchar* (*get_real_command) (GnomePieAction* self);
	void (*set_real_command) (GnomePieAction* self, const gchar* value);
	const gchar* (*get_display_command) (GnomePieAction* self);
	const gchar* (*get_name) (GnomePieAction* self);
	void (*set_name) (GnomePieAction* self, const gchar* value);
	const gchar* (*get_icon) (GnomePieAction* self);
	void (*set_icon) (GnomePieAction* self, const gchar* value);
	gboolean (*get_is_quickaction) (GnomePieAction* self);
	void (*set_is_quickaction) (GnomePieAction* self, gboolean value);
};

struct _GnomePiePieAction {
	GnomePieAction parent_instance;
	GnomePiePieActionPrivate * priv;
};

struct _GnomePiePieActionClass {
	GnomePieActionClass parent_class;
};

struct _GnomePiePieActionPrivate {
	gchar* _real_command;
	gchar* owned_name;
};

static gint GnomePiePieAction_private_offset;
static gpointer gnome_pie_pie_action_parent_class = NULL;

VALA_EXTERN GType gnome_pie_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieAction, g_object_unref)
VALA_EXTERN GType gnome_pie_pie_action_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePiePieAction, g_object_unref)
VALA_EXTERN void gnome_pie_action_activate (GnomePieAction* self,
                                guint32 time_stamp);
VALA_EXTERN const gchar* gnome_pie_action_get_real_command (GnomePieAction* self);
VALA_EXTERN void gnome_pie_action_set_real_command (GnomePieAction* self,
                                        const gchar* value);
VALA_EXTERN const gchar* gnome_pie_action_get_display_command (GnomePieAction* self);
VALA_EXTERN const gchar* gnome_pie_action_get_name (GnomePieAction* self);
VALA_EXTERN void gnome_pie_action_set_name (GnomePieAction* self,
                                const gchar* value);
VALA_EXTERN const gchar* gnome_pie_action_get_icon (GnomePieAction* self);
VALA_EXTERN void gnome_pie_action_set_icon (GnomePieAction* self,
                                const gchar* value);
VALA_EXTERN gpointer gnome_pie_action_registry_typedescription_ref (gpointer instance);
VALA_EXTERN void gnome_pie_action_registry_typedescription_unref (gpointer instance);
VALA_EXTERN GParamSpec* gnome_pie_action_registry_param_spec_typedescription (const gchar* name,
                                                                  const gchar* nick,
                                                                  const gchar* blurb,
                                                                  GType object_type,
                                                                  GParamFlags flags);
VALA_EXTERN void gnome_pie_action_registry_value_set_typedescription (GValue* value,
                                                          gpointer v_object);
VALA_EXTERN void gnome_pie_action_registry_value_take_typedescription (GValue* value,
                                                           gpointer v_object);
VALA_EXTERN gpointer gnome_pie_action_registry_value_get_typedescription (const GValue* value);
VALA_EXTERN GType gnome_pie_action_registry_typedescription_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePieActionRegistryTypeDescription, gnome_pie_action_registry_typedescription_unref)
VALA_EXTERN GnomePieActionRegistryTypeDescription* gnome_pie_pie_action_register (void);
VALA_EXTERN GnomePieActionRegistryTypeDescription* gnome_pie_action_registry_typedescription_new (void);
VALA_EXTERN GnomePieActionRegistryTypeDescription* gnome_pie_action_registry_typedescription_construct (GType object_type);
VALA_EXTERN void gnome_pie_action_registry_typedescription_set_name (GnomePieActionRegistryTypeDescription* self,
                                                         const gchar* value);
VALA_EXTERN void gnome_pie_action_registry_typedescription_set_icon (GnomePieActionRegistryTypeDescription* self,
                                                         const gchar* value);
VALA_EXTERN void gnome_pie_action_registry_typedescription_set_description (GnomePieActionRegistryTypeDescription* self,
                                                                const gchar* value);
VALA_EXTERN void gnome_pie_action_registry_typedescription_set_icon_name_editable (GnomePieActionRegistryTypeDescription* self,
                                                                       gboolean value);
VALA_EXTERN void gnome_pie_action_registry_typedescription_set_id (GnomePieActionRegistryTypeDescription* self,
                                                       const gchar* value);
VALA_EXTERN GnomePiePieAction* gnome_pie_pie_action_new (const gchar* id,
                                             gboolean is_quickaction);
VALA_EXTERN GnomePiePieAction* gnome_pie_pie_action_construct (GType object_type,
                                                   const gchar* id,
                                                   gboolean is_quickaction);
static void gnome_pie_pie_action_real_activate (GnomePieAction* base,
                                         guint32 time_stamp);
VALA_EXTERN void gnome_pie_pie_manager_open_pie (const gchar* id);
VALA_EXTERN GType gnome_pie_pie_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GnomePiePie, g_object_unref)
VALA_EXTERN GeeHashMap* gnome_pie_pie_manager_get_all_pies (void);
VALA_EXTERN const gchar* gnome_pie_pie_get_name (GnomePiePie* self);
VALA_EXTERN const gchar* gnome_pie_pie_get_icon (GnomePiePie* self);
static void gnome_pie_pie_action_finalize (GObject * obj);
static GType gnome_pie_pie_action_get_type_once (void);
static void _vala_gnome_pie_pie_action_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec);
static void _vala_gnome_pie_pie_action_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec);

static inline gpointer
gnome_pie_pie_action_get_instance_private (GnomePiePieAction* self)
{
	return G_STRUCT_MEMBER_P (self, GnomePiePieAction_private_offset);
}

GnomePieActionRegistryTypeDescription*
gnome_pie_pie_action_register (void)
{
	GnomePieActionRegistryTypeDescription* description = NULL;
	GnomePieActionRegistryTypeDescription* _tmp0_;
	GnomePieActionRegistryTypeDescription* result;
	_tmp0_ = gnome_pie_action_registry_typedescription_new ();
	description = _tmp0_;
	gnome_pie_action_registry_typedescription_set_name (description, _ ("Open Pie"));
	gnome_pie_action_registry_typedescription_set_icon (description, "gnome-pie");
	gnome_pie_action_registry_typedescription_set_description (description, _ ("Opens another Pie of Gnome-Pie. You may create sub menus this way."));
	gnome_pie_action_registry_typedescription_set_icon_name_editable (description, FALSE);
	gnome_pie_action_registry_typedescription_set_id (description, "pie");
	result = description;
	return result;
}

GnomePiePieAction*
gnome_pie_pie_action_construct (GType object_type,
                                const gchar* id,
                                gboolean is_quickaction)
{
	GnomePiePieAction * self = NULL;
	g_return_val_if_fail (id != NULL, NULL);
	self = (GnomePiePieAction*) g_object_new (object_type, "name", "", "icon", "", "real-command", id, "is-quickaction", is_quickaction, NULL);
	return self;
}

GnomePiePieAction*
gnome_pie_pie_action_new (const gchar* id,
                          gboolean is_quickaction)
{
	return gnome_pie_pie_action_construct (GNOME_PIE_TYPE_PIE_ACTION, id, is_quickaction);
}

static void
gnome_pie_pie_action_real_activate (GnomePieAction* base,
                                    guint32 time_stamp)
{
	GnomePiePieAction * self;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	self = (GnomePiePieAction*) base;
	_tmp0_ = gnome_pie_action_get_real_command ((GnomePieAction*) self);
	_tmp1_ = _tmp0_;
	gnome_pie_pie_manager_open_pie (_tmp1_);
}

static const gchar*
gnome_pie_pie_action_real_get_real_command (GnomePieAction* base)
{
	const gchar* result;
	GnomePiePieAction* self;
	const gchar* _tmp0_;
	self = (GnomePiePieAction*) base;
	_tmp0_ = self->priv->_real_command;
	result = _tmp0_;
	return result;
}

static void
gnome_pie_pie_action_real_set_real_command (GnomePieAction* base,
                                            const gchar* value)
{
	GnomePiePieAction* self;
	gchar* old_value;
	self = (GnomePiePieAction*) base;
	old_value = gnome_pie_pie_action_real_get_real_command (base);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_real_command);
		self->priv->_real_command = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gnome_pie_pie_action_properties[GNOME_PIE_PIE_ACTION_REAL_COMMAND_PROPERTY]);
	}
}

static const gchar*
gnome_pie_pie_action_real_get_display_command (GnomePieAction* base)
{
	const gchar* result;
	GnomePiePieAction* self;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	self = (GnomePiePieAction*) base;
	_tmp0_ = gnome_pie_action_get_name ((GnomePieAction*) self);
	_tmp1_ = _tmp0_;
	result = _tmp1_;
	return result;
}

static const gchar*
gnome_pie_pie_action_real_get_name (GnomePieAction* base)
{
	const gchar* result;
	GnomePiePieAction* self;
	GnomePiePie* referee = NULL;
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gpointer _tmp4_;
	GnomePiePie* _tmp5_;
	self = (GnomePiePieAction*) base;
	_tmp0_ = gnome_pie_pie_manager_get_all_pies ();
	_tmp1_ = _tmp0_;
	_tmp2_ = gnome_pie_action_get_real_command ((GnomePieAction*) self);
	_tmp3_ = _tmp2_;
	_tmp4_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp1_, _tmp3_);
	referee = (GnomePiePie*) _tmp4_;
	_tmp5_ = referee;
	if (_tmp5_ != NULL) {
		GnomePiePie* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		gchar* _tmp9_;
		const gchar* _tmp10_;
		_tmp6_ = referee;
		_tmp7_ = gnome_pie_pie_get_name (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = g_strconcat ("↪", _tmp8_, NULL);
		_g_free0 (self->priv->owned_name);
		self->priv->owned_name = _tmp9_;
		_tmp10_ = self->priv->owned_name;
		result = _tmp10_;
		_g_object_unref0 (referee);
		return result;
	}
	result = "";
	_g_object_unref0 (referee);
	return result;
}

static void
gnome_pie_pie_action_real_set_name (GnomePieAction* base,
                                    const gchar* value)
{
	GnomePiePieAction* self;
	self = (GnomePiePieAction*) base;
	g_object_notify_by_pspec ((GObject *) self, gnome_pie_pie_action_properties[GNOME_PIE_PIE_ACTION_NAME_PROPERTY]);
}

static const gchar*
gnome_pie_pie_action_real_get_icon (GnomePieAction* base)
{
	const gchar* result;
	GnomePiePieAction* self;
	GnomePiePie* referee = NULL;
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gpointer _tmp4_;
	GnomePiePie* _tmp5_;
	self = (GnomePiePieAction*) base;
	_tmp0_ = gnome_pie_pie_manager_get_all_pies ();
	_tmp1_ = _tmp0_;
	_tmp2_ = gnome_pie_action_get_real_command ((GnomePieAction*) self);
	_tmp3_ = _tmp2_;
	_tmp4_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp1_, _tmp3_);
	referee = (GnomePiePie*) _tmp4_;
	_tmp5_ = referee;
	if (_tmp5_ != NULL) {
		GnomePiePie* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		_tmp6_ = referee;
		_tmp7_ = gnome_pie_pie_get_icon (_tmp6_);
		_tmp8_ = _tmp7_;
		result = _tmp8_;
		_g_object_unref0 (referee);
		return result;
	}
	result = "";
	_g_object_unref0 (referee);
	return result;
}

static void
gnome_pie_pie_action_real_set_icon (GnomePieAction* base,
                                    const gchar* value)
{
	GnomePiePieAction* self;
	self = (GnomePiePieAction*) base;
	g_object_notify_by_pspec ((GObject *) self, gnome_pie_pie_action_properties[GNOME_PIE_PIE_ACTION_ICON_PROPERTY]);
}

static void
gnome_pie_pie_action_class_init (GnomePiePieActionClass * klass,
                                 gpointer klass_data)
{
	gnome_pie_pie_action_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GnomePiePieAction_private_offset);
	((GnomePieActionClass *) klass)->activate = (void (*) (GnomePieAction*, guint32)) gnome_pie_pie_action_real_activate;
	GNOME_PIE_ACTION_CLASS (klass)->get_real_command = (const gchar* (*) (GnomePieAction*)) gnome_pie_pie_action_real_get_real_command;
	GNOME_PIE_ACTION_CLASS (klass)->set_real_command = (void (*) (GnomePieAction*, const gchar*)) gnome_pie_pie_action_real_set_real_command;
	GNOME_PIE_ACTION_CLASS (klass)->get_display_command = (const gchar* (*) (GnomePieAction*)) gnome_pie_pie_action_real_get_display_command;
	GNOME_PIE_ACTION_CLASS (klass)->get_name = (const gchar* (*) (GnomePieAction*)) gnome_pie_pie_action_real_get_name;
	GNOME_PIE_ACTION_CLASS (klass)->set_name = (void (*) (GnomePieAction*, const gchar*)) gnome_pie_pie_action_real_set_name;
	GNOME_PIE_ACTION_CLASS (klass)->get_icon = (const gchar* (*) (GnomePieAction*)) gnome_pie_pie_action_real_get_icon;
	GNOME_PIE_ACTION_CLASS (klass)->set_icon = (void (*) (GnomePieAction*, const gchar*)) gnome_pie_pie_action_real_set_icon;
	G_OBJECT_CLASS (klass)->get_property = _vala_gnome_pie_pie_action_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gnome_pie_pie_action_set_property;
	G_OBJECT_CLASS (klass)->finalize = gnome_pie_pie_action_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_PIE_ACTION_REAL_COMMAND_PROPERTY, gnome_pie_pie_action_properties[GNOME_PIE_PIE_ACTION_REAL_COMMAND_PROPERTY] = g_param_spec_string ("real-command", "real-command", "real-command", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_PIE_ACTION_DISPLAY_COMMAND_PROPERTY, gnome_pie_pie_action_properties[GNOME_PIE_PIE_ACTION_DISPLAY_COMMAND_PROPERTY] = g_param_spec_string ("display-command", "display-command", "display-command", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_PIE_ACTION_NAME_PROPERTY, gnome_pie_pie_action_properties[GNOME_PIE_PIE_ACTION_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GNOME_PIE_PIE_ACTION_ICON_PROPERTY, gnome_pie_pie_action_properties[GNOME_PIE_PIE_ACTION_ICON_PROPERTY] = g_param_spec_string ("icon", "icon", "icon", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
gnome_pie_pie_action_instance_init (GnomePiePieAction * self,
                                    gpointer klass)
{
	self->priv = gnome_pie_pie_action_get_instance_private (self);
}

static void
gnome_pie_pie_action_finalize (GObject * obj)
{
	GnomePiePieAction * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GNOME_PIE_TYPE_PIE_ACTION, GnomePiePieAction);
	_g_free0 (self->priv->_real_command);
	_g_free0 (self->priv->owned_name);
	G_OBJECT_CLASS (gnome_pie_pie_action_parent_class)->finalize (obj);
}

static GType
gnome_pie_pie_action_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GnomePiePieActionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gnome_pie_pie_action_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GnomePiePieAction), 0, (GInstanceInitFunc) gnome_pie_pie_action_instance_init, NULL };
	GType gnome_pie_pie_action_type_id;
	gnome_pie_pie_action_type_id = g_type_register_static (GNOME_PIE_TYPE_ACTION, "GnomePiePieAction", &g_define_type_info, 0);
	GnomePiePieAction_private_offset = g_type_add_instance_private (gnome_pie_pie_action_type_id, sizeof (GnomePiePieActionPrivate));
	return gnome_pie_pie_action_type_id;
}

GType
gnome_pie_pie_action_get_type (void)
{
	static volatile gsize gnome_pie_pie_action_type_id__once = 0;
	if (g_once_init_enter (&gnome_pie_pie_action_type_id__once)) {
		GType gnome_pie_pie_action_type_id;
		gnome_pie_pie_action_type_id = gnome_pie_pie_action_get_type_once ();
		g_once_init_leave (&gnome_pie_pie_action_type_id__once, gnome_pie_pie_action_type_id);
	}
	return gnome_pie_pie_action_type_id__once;
}

static void
_vala_gnome_pie_pie_action_get_property (GObject * object,
                                         guint property_id,
                                         GValue * value,
                                         GParamSpec * pspec)
{
	GnomePiePieAction * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GNOME_PIE_TYPE_PIE_ACTION, GnomePiePieAction);
	switch (property_id) {
		case GNOME_PIE_PIE_ACTION_REAL_COMMAND_PROPERTY:
		g_value_set_string (value, gnome_pie_action_get_real_command ((GnomePieAction*) self));
		break;
		case GNOME_PIE_PIE_ACTION_DISPLAY_COMMAND_PROPERTY:
		g_value_set_string (value, gnome_pie_action_get_display_command ((GnomePieAction*) self));
		break;
		case GNOME_PIE_PIE_ACTION_NAME_PROPERTY:
		g_value_set_string (value, gnome_pie_action_get_name ((GnomePieAction*) self));
		break;
		case GNOME_PIE_PIE_ACTION_ICON_PROPERTY:
		g_value_set_string (value, gnome_pie_action_get_icon ((GnomePieAction*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gnome_pie_pie_action_set_property (GObject * object,
                                         guint property_id,
                                         const GValue * value,
                                         GParamSpec * pspec)
{
	GnomePiePieAction * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GNOME_PIE_TYPE_PIE_ACTION, GnomePiePieAction);
	switch (property_id) {
		case GNOME_PIE_PIE_ACTION_REAL_COMMAND_PROPERTY:
		gnome_pie_action_set_real_command ((GnomePieAction*) self, g_value_get_string (value));
		break;
		case GNOME_PIE_PIE_ACTION_NAME_PROPERTY:
		gnome_pie_action_set_name ((GnomePieAction*) self, g_value_get_string (value));
		break;
		case GNOME_PIE_PIE_ACTION_ICON_PROPERTY:
		gnome_pie_action_set_icon ((GnomePieAction*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

